package com.taauav.admin.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.taauav.common.bean.Response;
import com.taauav.common.constant.PermissionConstants;
import com.taauav.admin.entity.SysAdmin;
import com.taauav.admin.service.ISysAdminService;
import com.taauav.admin.service.ISysCityService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 管理员表 前端控制器
 * </p>
 *
 * @author dyg
 * @since 2019-11-04
 */
@RestController
@RequestMapping("/admin")
public class
SysAdminController {
    @Autowired
    private ISysAdminService iSysAdminService;
    @Autowired
    private Response response;
    @Autowired
    private ISysCityService cityService;

    private static final String controllerName = "admin";

    /**
     * 管理员列表接口
     *
     * @param map
     * @return
     */
    @PostMapping("/index")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.LIST_PERMISSION)
    public Response index(@RequestBody(required = false) Map<String, String> map) {
        return iSysAdminService.findAdminPageList(map);
    }

    /**
     * 编辑-提交接口
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/edit")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response edit(@RequestBody @Valid SysAdmin map, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            String msg = bindingResult.getFieldError().getDefaultMessage();
            return response.failure(msg);
        }
        return iSysAdminService.editAdminInfo(map);
    }

    /**
     * 编辑-获取原数据接口
     *
     * @param id
     * @return
     */
    @GetMapping("/getAdminInfo")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response getAdminInfo(Integer id) {
        SysAdmin admin = iSysAdminService.getAdminInfo(id);
        if (admin == null) {
            return response.failure("操作失败", null);
        }
        return response.success("操作成功", admin);
    }

    /**
     * 添加管理员
     *
     * @param map
     * @return
     */
    @PostMapping("/add")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.ADD_PERMISSION)
    public Response add(@RequestBody @Valid SysAdmin map, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            String msg = bindingResult.getFieldError().getDefaultMessage();
            return response.failure(msg);
        }
        return iSysAdminService.editAdminInfo(map);
    }

    /**
     * 删除管理员账号
     *
     * @param map
     * @return
     */
    @PostMapping("/drop")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.REMOVE_PERMISSION)
    public Response dropAdmin(@RequestBody Map<String, String> map) {
        map.put("act", "drop");
        return iSysAdminService.dealAdmin(map);
    }

    /**
     * 重置密码接口
     *
     * @param map
     * @return
     */
    @PostMapping("/reset")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.PASSWORD_PERMISSION)
    public Response resetPassword(@RequestBody Map<String, String> map) {
        map.put("act", "reset");
        return iSysAdminService.dealAdmin(map);
    }

    /**
     * 修改账户状态接口
     *
     * @param map
     * @return
     */
    @PostMapping("/editStatus")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.STATUS_PERMISSION)
    public Response editStatus(@RequestBody Map<String, String> map) {
        map.put("act", "changeStatus");
        return iSysAdminService.dealAdmin(map);
    }

    /**
     * 设置账户权限接口
     *
     * @param map
     * @return
     */
    @PostMapping("/setPermit")
    @RequiresPermissions("admin:setPermit")
    public Response setPermit(@RequestBody(required = false) Map<String, String> map) {
        return iSysAdminService.setPermit(map);
    }

    /**
     * 获取所有管理员（组装option用）
     *
     * @return
     */
    @PostMapping("/getAdminList")
    public Response getAdminList() {
        return iSysAdminService.getAdminList();
    }

    /**
     * 获取角色数组
     *
     * @return
     */
    @PostMapping("/authList")
    public Response getAuthGroupList() {
        return iSysAdminService.getAuthGroupList();
    }

    /**
     * 获取城市数组
     *
     * @return
     */
    @GetMapping("/getCityList")
    public Response getCityList() {
        //区属权限
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("mark", 1);
        wrapper.eq("pid", 320100);
        wrapper.select("id,name");
        List<Map<String, Object>> cityList = cityService.listMaps(wrapper);
        return response.success("操作成功", cityList);
    }

    /**
     * 获取飞手列表【分配任务时使用】
     *
     * @return
     */
    @PostMapping("/getFlyHandList")
    public Response getFlyHandList() {
        return response.success(iSysAdminService.getAdminListByGroupId(6));
    }
}
