package com.taauav.admin.controller;


import com.taauav.common.bean.Response;
import com.taauav.common.constant.PermissionConstants;
import com.taauav.admin.entity.SysConfig;
import com.taauav.admin.mapper.SysConfigMapper;
import com.taauav.admin.service.ISysConfigService;
import com.taauav.common.util.FunctionUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * <p>
 * 系统配置表 前端控制器
 * </p>
 *
 * @author dyg
 * @since 2019-11-12
 */
@RestController
@RequestMapping("/config")
public class SysConfigController {
    @Autowired
    private ISysConfigService configService;
    @Autowired
    private Response response;
    @Autowired
    private SysConfigMapper configMapper;

    private static final String controllerName = "config";

    /**
     * 列表数据接口
     * @param map
     * @return
     */
    @PostMapping("/index")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.LIST_PERMISSION)
    public Response index(@RequestBody(required = false) Map<String, String> map) {
        return configService.getPageList(map);
    }

    /**
     * 编辑-提交保存接口
     * @param map
     * @return
     */
    @PostMapping(value = "/edit")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response edit(@RequestBody SysConfig map) {
        return configService.editData(map);
    }

    /**
     * 编辑-获取原数据接口
     * @param id
     * @return
     */
    @GetMapping("/getConfigInfo")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response getConfigInfo(Integer id) {
        SysConfig configInfo = configService.getConfigById(id);
        return response.success("操作成功", configInfo);
    }

    /**
     * 新增配置接口
     * @param map
     * @return
     */
    @PostMapping("/add")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.ADD_PERMISSION)
    public Response add(@RequestBody SysConfig map) {
        return configService.editData(map);
    }

    /**
     * 删除配置接口
     * @param id
     * @return
     */
    @PostMapping("/drop")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.REMOVE_PERMISSION)
    public Response drop(@RequestBody(required = false) Map<String, String> map) {
        if (map == null) {
            return response.failure("参数不能为空");
        }
        String id = "id";
        if (FunctionUtils.isEmpty(id, map) || !FunctionUtils.isNumeric(map.get(id)) || Integer.valueOf(map.get(id)) <= 0) {
            return response.failure("配置id不合法");
        }
        SysConfig config = configService.getConfigById(Integer.valueOf(map.get(id)));
        if (config == null) {
            return response.failure("配置信息不存在");
        }
        config.setMark(0);
        configMapper.updateById(config);
        return response.success("操作成功");
    }

    /**
     * 设置配置状态接口
     * @param map
     * @return
     */
    @PostMapping("/setStatus")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.STATUS_PERMISSION)
    public Response setStatus(@RequestBody Map<String, Integer> map) {
        return configService.setStatus(map);
    }
}
