package com.taauav.admin.controller;


import com.taauav.common.bean.Response;
import com.taauav.common.constant.PermissionConstants;
import com.taauav.admin.entity.SysDep;
import com.taauav.admin.service.ISysDepService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * <p>
 * 部门管理表 前端控制器
 * </p>
 *
 * @author dyg
 * @since 2019-11-07
 */
@RestController
@RequestMapping("/dep")
public class SysDepController {
    @Autowired
    private ISysDepService iSysDepService;

    private static final String controllerName = "dep";

    /**
     * 部门列表
     * @return
     */
    @PostMapping("/index")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.LIST_PERMISSION)
    public Response index() {
        return iSysDepService.index();
    }


    /**
     * 编辑部门
     * @param map
     * @return
     */
    @RequestMapping(value = "/edit", method = {RequestMethod.POST, RequestMethod.GET})
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response edit(@RequestBody(required = false) SysDep map) {
        return iSysDepService.edit(map);
    }

    /**
     * 获取部门数据信息
     * @param id
     * @return
     */
    @GetMapping("/getDepInfo")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response getDepInfo(Integer id) {
        return iSysDepService.getDepInfo(id);
    }

    /**
     * 添加部门
     * @param map
     * @return
     */
    @PostMapping("/add")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.ADD_PERMISSION)
    public Response add(@RequestBody(required = true) SysDep map) {
        return iSysDepService.edit(map);
    }

    /**
     * 删除
     * @param map
     * @return
     */
    @PostMapping("/drop")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.REMOVE_PERMISSION)
    public Response drop(@RequestBody(required = true) Map<String, String> map) {
        return iSysDepService.drop(map);
    }
}
