package com.taauav.admin.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.taauav.common.bean.Response;
import com.taauav.common.constant.PermissionConstants;
import com.taauav.admin.entity.SysDictType;
import com.taauav.admin.mapper.SysDictTypeMapper;
import com.taauav.admin.service.ISysDictTypeService;
import com.taauav.common.util.DateUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 系统字典分类表 前端控制器
 * </p>
 *
 * @author dyg
 * @since 2019-11-14
 */
@RestController
@RequestMapping("/dicttype")
public class SysDictTypeController {
    @Autowired
    private ISysDictTypeService dictTypeService;
    @Autowired
    private SysDictTypeMapper dictTypeMapper;
    @Autowired
    private Response response;

    private static final String controllerName = "dicttype";

    @PostMapping("/index")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.LIST_PERMISSION)
    public Response index(@RequestBody(required = false) Map<String, String> map) {
        return dictTypeService.getPageList(map);
    }

    /**
     * 编辑-提交接口
     *
     * @param map
     * @return
     */
    @PostMapping("/edit")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response edit(@RequestBody SysDictType map) {
        return dictTypeService.editData(map);
    }

    /**
     * 编辑-获取原数据
     *
     * @param id
     * @return
     */
    @GetMapping("/getEditInfo")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response getEditInfo(Integer id) {
        if (id <= 0) {
            return response.failure("分类id不合法");
        }
        SysDictType dictType = dictTypeService.getDictTypeById(id);
        if (dictType == null) {
            return response.failure("对应分类数据不存在");
        }
        return response.success("操作成功", dictType);
    }

    /**
     * 新增分类接口
     *
     * @param map
     * @return
     */
    @PostMapping("/add")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.ADD_PERMISSION)
    public Response add(@RequestBody SysDictType map) {
        return dictTypeService.editData(map);
    }

    /**
     * 删除分类接口
     *
     * @param id
     * @return
     */
    @PostMapping("/drop")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.REMOVE_PERMISSION)
    public Response drop(@RequestBody Integer id) {
        if (id <= 0) {
            return response.failure("字典分类id不合法");
        }
        SysDictType dictType = dictTypeService.getDictTypeById(id);
        if (dictType == null) {
            return response.failure("字典分类信息不存在");
        }
        dictType.setMark(0);
        dictType.setUpdateTime(DateUtil.now());
        dictType.setUpdateUser(ShiroUtils.getAdminId());
        dictTypeMapper.updateById(dictType);
        return response.success("操作成功");
    }

    /**
     * 获取字典分类全部数据
     *
     * @return
     */
    @GetMapping("/dictTypeList")
    public Response getDictTypeList() {
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("mark", 1);
        wrapper.orderByAsc("sort", "id");
        List<Map<String, Object>> list = dictTypeMapper.selectList(wrapper);
        return response.success("操作成功", list);
    }
}
