package com.taauav.admin.controller;


import com.taauav.admin.entity.SysCity;
import com.taauav.admin.service.ITauvCityService;
import com.taauav.common.bean.Response;
import com.taauav.common.constant.PermissionConstants;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.math.BigInteger;

/**
 * <p>
 * 用户组表 前端控制器
 * </p>
 *
 * @author dyg
 * @since 2020-04-01
 */
@RestController
@RequestMapping("/agency")
public class TauvCityController {

    @Autowired
    private ITauvCityService tauvAgencyService;

    @Autowired
    private Response response;

    private static final String controllerName = "agency";

    /**
     * 获取机构列表
     *
     * @return
     */
    @PostMapping("/index")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.LIST_PERMISSION)
    public Response index() {
        return tauvAgencyService.getList();
    }

    /**
     * 添加机构
     *
     * @param entity        实体对象
     * @param bindingResult
     * @return
     */
    @PostMapping("/add")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.ADD_PERMISSION)
    public Response add(@RequestBody @Valid SysCity entity, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            String message = bindingResult.getFieldError().getDefaultMessage();
            return response.failure(message);
        }
        return tauvAgencyService.add(entity);
    }

    /**
     * 获取机构详情
     *
     * @param id 机构ID
     * @return
     */
    @GetMapping("/info")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response info(BigInteger id) {
        return tauvAgencyService.info(id);
    }

    /**
     * 编辑机构
     *
     * @param entity        实体对象
     * @param bindingResult
     * @return
     */
    @PostMapping("/edit")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response edit(@RequestBody @Valid SysCity entity, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            String message = bindingResult.getFieldError().getDefaultMessage();
            return response.failure(message);
        }
        return tauvAgencyService.edit(entity);
    }

    /**
     * 删除机构
     *
     * @param id 机构ID
     * @return
     */
    @PostMapping("/drop")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.REMOVE_PERMISSION)
    public Response delete(BigInteger id) {
        return tauvAgencyService.delete(id);
    }

    /**
     * 设置状态
     *
     * @param entity 实体对象
     * @return
     */
    @PostMapping("/setStatus")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.STATUS_PERMISSION)
    public Response setStatus(@RequestBody SysCity entity) {
        return tauvAgencyService.setStatus(entity);
    }

    /**
     * 获取子级城市列表
     *
     * @param pid 上级ID
     * @return
     */
    @PostMapping("/getChildCityList")
    public Response getChildCityList(BigInteger pid) {
        return tauvAgencyService.getChildCityList(pid);
    }

}
