package com.taauav.admin.controller;


import com.taauav.common.bean.Response;
import com.taauav.common.constant.PermissionConstants;
import com.taauav.admin.entity.SysAdmin;
import com.taauav.admin.entity.TauvReport;
import com.taauav.admin.service.ISysCityService;
import com.taauav.admin.service.ITauvReportService;
import com.taauav.common.util.ShiroUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * 巡检报告表 前端控制器
 * </p>
 *
 * @author dyg
 * @since 2019-11-22
 */
@RestController
@RequestMapping("/report")
public class TauvReportController extends BaseController {
    @Autowired
    private ITauvReportService iTauvReportService;
    @Autowired
    private Response response;
    @Autowired
    private ISysCityService cityService;

    /**
     * 报告生成列表
     * @param map
     * @return
     */
    @PostMapping("generateList")
    @RequiresPermissions("report:generateList")
    public Response generateList(@RequestBody(required = false) Map<String,Object> map) {
        return iTauvReportService.getGenerateList(map);
    }

    /**
     * 报告审核
     * @param map
     * @return
     */
    @PostMapping("checkList")
    @RequiresPermissions("report:checkList")
    public Response checkList(@RequestBody(required = false) Map<String,Object> map) {
        return iTauvReportService.getCheckList(map);
    }

    /**
     * 报告查询
     * @param map
     * @return
     */
    @PostMapping("searchList")
    @RequiresPermissions("report:searchList")
    public Response searchList(@RequestBody(required = false) Map<String,Object> map) {
        return iTauvReportService.getSearchList(map);
    }

    /**
     * 报告录入列表
     * @param map
     * @return
     */
    @PostMapping("inputList")
    @RequiresPermissions("report:inputList")
    public Response inputList(@RequestBody(required = false) Map<String,Object> map) {
        return iTauvReportService.getInputList(map);
    }

    /**
     * 报告详情
     * @param id
     * @return
     */
    @GetMapping("detail")
    @RequiresPermissions("report:" + PermissionConstants.VIEW_PERMISSION)
    public Response detail(@RequestParam("id") Integer id) {
        Map<String,Object> data = iTauvReportService.getDetailById(id,"detail");
        return response.success(data);
    }

    /**
     * 报告生成
     * @param id
     * @return
     */
    @GetMapping("generate")
    @RequiresPermissions("report:generate")
    public Response generate(@RequestParam("id") Integer id) {
        Map<String,Object> data = iTauvReportService.getDetailById(id, "generate");
        return response.success(data);
    }

    /**
     * 报告生成-保存
     * @param map
     * @return
     */
    @PostMapping("generateSub")
    @RequiresPermissions("report:generate")
    public Response generateSub(@RequestBody Map<String, Object> map) {
        return iTauvReportService.editSub(map, "generate");
    }

    /**
     * 报告编辑
     * @param id
     * @return
     */
    @GetMapping("edit")
    @RequiresPermissions("report:" + PermissionConstants.EDIT_PERMISSION)
    public Response edit(@RequestParam("id") Integer id) {
        Map<String,Object> data = iTauvReportService.getDetailById(id,"edit");
        return response.success(data);
    }

    /**
     * 编辑保存
     * @param map
     * @return
     */
    @PostMapping("editSub")
    @RequiresPermissions("report:" + PermissionConstants.EDIT_PERMISSION)
    public Response editSub(@RequestBody Map<String,Object> map) {
        return iTauvReportService.editSub(map, "editSub");
    }

    /**
     * 审核报告-保存
     * @param map
     * @return
     */
    @PostMapping("checkSub")
    @RequiresPermissions("report:checkSub")
    public Response chekcSub(@RequestBody Map<String,Object> map) {
        return iTauvReportService.editSub(map, "checkSub");
    }

    /**
     * 编辑报告视频，图片地址
     * @param map
     * @return
     */
    @PostMapping("editUrl")
    @RequiresPermissions("report:editUrl")
    public Response editUrl(@RequestBody Map<String,Object> map) {
        return iTauvReportService.editUrl(map);
    }

    /**
     * 根据编号获取数据
     * @param id
     * @return
     */
    @GetMapping("view")
    public Response info(@RequestParam("id") Integer id) {
        Map<String,Object> map = new HashMap<>(8);
        TauvReport reportInfo = iTauvReportService.getInfoById(id);
        map.put("id", reportInfo.getId());
        map.put("driverArea",reportInfo.getDriverAreaText());
        map.put("dirverName", reportInfo.getDriverName());
        map.put("driverStart", reportInfo.getDriverStart());
        map.put("driverEnd", reportInfo.getDriverEnd());
        map.put("inspectStartTime", reportInfo.getFormatInspectStartTime());
        map.put("videoUrl", reportInfo.getFormatVideoUrl());
        map.put("imageUrl", reportInfo.getFormatImageUrl());
        return response.success(map);
    }

    /**
     * 获取基础数据
     * @return
     */
    @GetMapping("/basicData")
    public Response basicData() {
        Map<String, Object> result = new HashMap<>(4);
        SysAdmin admin = ShiroUtils.getAdminInfo();
        //区域数组
        result.put("areaList",cityService.getCityListByPidAndAdmin(320100));
        //状态数组
        TauvReport report = new TauvReport();
        result.put("statusList", report.getStatusList());
        //是否省/国考河道
        result.put("driverExamList", report.getDriverExamList());
        return response.success("操作成功", result);
    }

    /**
     * 删除报告
     * @param map
     * @return
     */
    @PostMapping("/dropReport")
    @RequiresPermissions("report:" + PermissionConstants.REMOVE_PERMISSION)
    public Response dropReport(@RequestBody Map<String, Object> map) {
        return iTauvReportService.dealReport(map, "drop");
    }

    /**
     * 重处理报告
     * @param map
     * @return
     */
    @PostMapping("/reProcess")
    @RequiresPermissions("report:reProcess")
    public Response reProcess(@RequestBody Map<String, Object> map) {
        return iTauvReportService.dealReport(map, "reProcess");
    }
}
