package com.taauav.admin.entity;

import com.baomidou.mybatisplus.annotation.TableField;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.taauav.common.domain.Entity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.springframework.format.annotation.DateTimeFormat;

/**
 * <p>
 * 巡检报告表
 * </p>
 *
 * @author dyg
 * @since 2019-11-22
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class TauvReport extends Entity {

    private static final long serialVersionUID = 1L;

    /**
     * 报告编号
     */
    private String reportNo;

    /**
     * 巡检任务ID
     */
    private Integer inspectId;

    /**
     * 飞行小组编号
     */
    private Integer flightGroup;

    /**
     * 巡检河道ID
     */
    private Integer inspectDriverId;

    /**
     * 任务单号
     */
    private String inspectNo;

    private Integer num;
    /**
     * 任务名称
     */
    private String inspectName;

    /**
     * 河流名称
     */
    private String driverName;

    /**
     * 河流区域ID
     */
    private BigInteger driverArea;
    @TableField(exist = false)
    private String driverAreaText;
    /**
     * 河流起点
     */
    private String driverStart;

    /**
     * 河流终点
     */
    private String driverEnd;

    /**
     * 是否省/国考河道：1是 2否
     */
    private Integer driverExam;

    /**
     * 巡检总长
     */
    private String inspectLength;

    /**
     * 巡检开始时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date inspectStartTime;
    @TableField(exist = false)
    private String formatInspectStartTime;
    /**
     * 巡检结束时间
     */
    private Integer inspectEndTime;

    /**
     * 巡检时间
     */
    private Integer executionTime;

    /**
     * 原始视频地址
     */
    private String originalVideoUrl;

    /**
     * 视频地址
     */
    private String videoUrl;
    @TableField(exist = false)
    private String formatVideoUrl;

    /**
     * 正视图地址
     */
    private String imageUrl;
    @TableField(exist = false)
    private String formatImageUrl;
    /**
     * 电子报告地址
     */
    private String reportUrl;

    /**
     * 群众满意度(考核分)
     */
    private Integer manyiExamineScore;

    /**
     * 群众满意度(校核分)
     */
    private Integer manyiCheckScore;

    /**
     * 知晓率得分(考核分)
     */
    private Integer awareExamineScore;

    /**
     * 知晓率得分(校核分)
     */
    private Integer awareCheckScore;

    /**
     * 考核分
     */
    private Integer totalExamineScore;

    /**
     * 校核分
     */
    private Integer totalCheckScore;

    /**
     * 报告描述
     */
    @TableField(value = "`desc`")
    private String desc;

    /**
     * 创建人
     */
    private Integer inputUser;

    /**
     * 创建时间
     */
    private Integer inputTime;

    /**
     * 是否省/国考
     *
     * @return
     */
    public Map<Integer, String> getDriverExamList() {
        Map<Integer, String> map = new HashMap<>(2);
        map.put(1, "是");
        map.put(2, "否");
        return map;
    }

    /**
     * 状态数组
     *
     * @return
     */
    public Map<Integer, String> getStatusList() {
        Map<Integer, String> map = new HashMap<>(5);
        map.put(1, "待生成");
        map.put(2, "审核中");
        map.put(3, "审核通过");
        map.put(4, "审核驳回");
        return map;
    }
}
