package com.taauav.admin.service;

import com.taauav.common.bean.Response;
import com.taauav.admin.entity.TauvInspectFile;
import com.taauav.common.service.IBaseService;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 巡检附件表 服务类
 * </p>
 *
 * @author dyg
 * @since 2019-11-14
 */
public interface ITauvInspectFileService extends IBaseService<TauvInspectFile> {
    /**
     * 根据条件获取分页数据
     *
     * @return
     */
    Response getPageList(Map<String, Object> map, String actType);

    /**
     * 上传图片
     *
     * @param map
     * @return
     * @throws IOException
     */
    Response uploadPic(Map<String, Object> map) throws IOException;

    Response savePic(Map<String, String> map);

    Response cancelMark(Integer id);

    Response dropPic(Integer id);

    Response view(Integer id);

    Response setMarkFinish(Integer id);

    String downFile(File file);

    Response getDocumentList();

    Response getReviewPic(Integer id);

    Response reviewPic(List<Map<String, String>> map);

    Response reviewFinish(Integer id);

    /**
     * 任务删除
     *
     * @param id
     * @return
     */
    Response drop(Integer id);

    /**
     * 根据编号获取数据
     *
     * @param id
     * @return
     */
    TauvInspectFile getInfoById(Integer id);

    /**
     * 文件下载
     *
     * @param ids
     * @return
     */
    File getDownloadFileByIds(String ids);

    Integer getReviewNumByInspectDriverId(Integer questionId, Integer inspectDriverId);

    List<Map<String, Object>> getReviewDataByInspectDriverId(Integer inspectDriverId);

    /**
     * 根据河道编号获取河道类型下问题图片的数量
     *
     * @param driverArea       河道区域
     * @param inspectDriverId
     * @param driverExam
     * @param inspectStartTime
     * @param inspectEndTime
     * @return
     */
    List<Map<String, Object>> getNumByFileDocument(String driverArea, Integer inspectDriverId, String driverExam, Integer inspectStartTime, Integer inspectEndTime);

    /**
     * 根据河道编号和图片类型获取河道类型下问题图片的数量
     *
     * @param inspectDriverId
     * @param fileDocument
     * @return
     */
    List<Map<String, Object>> getReviewDataByInspectDriverIdAndFileDocument(Integer inspectDriverId, String fileDocument);

    /**
     * 根据河道任务编号获取数据数量
     *
     * @param inspectDriverId
     * @return
     */
    Integer getTotalFileByInspectDriverId(Integer inspectDriverId);

    /**
     * 根据河道任务编号获取数据
     *
     * @param inspectDriverId
     * @return
     */
    TauvInspectFile getInfoByInspectDriverId(Integer inspectDriverId);

    /**
     * 根据河道任务编号获取数据
     *
     * @param inspectDriverId
     * @return
     */
    List<TauvInspectFile> getListByInspectDriverId(Integer inspectDriverId);

    /**
     * 根据任务河道ID和问题ID获取数据
     *
     * @param inspectDriverId
     * @param questionId
     * @return
     */
    TauvInspectFile getInfoByDriverIdAndQuestionId(Integer inspectDriverId, Integer questionId);
}
