package com.taauav.admin.service.impl;

import com.taauav.common.bean.Response;
import com.taauav.admin.entity.TauvInspectFile;
import com.taauav.admin.entity.TauvReport;
import com.taauav.admin.service.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>地图统计业务实现</p>
 *
 * @author : dyg
 * @date : 2019-12-07 14:04
 **/
@Service("iStatisticsMapService")
public class StatisticsMapServiceImpl implements IStatisticsMapService {
    @Autowired
    private ISysCityService iSysCityService;
    @Autowired
    private ITauvReportService iTauvReportService;
    @Autowired
    private ITauvInspectFileService iTauvInspectFileService;
    @Value("${server.UPLOAD_URL}")
    private String uploadUrl;
    @Autowired
    private Response response;

    /**
     * 获取所有区域数据
     * @return
     */
    @Override
    public Response getIndexData() {
        List<Map<String,Object>> cityList = iSysCityService.getCityListByPidAndAdmin(320100);
        if (null != cityList) {
            Map<String,String> queryMap = new HashMap<>(1);
            for (Map<String,Object> city : cityList) {
                queryMap.put("driverArea", city.get("id").toString());
                queryMap.put("question", "true");
                Integer num = iTauvReportService.getNumByCond(queryMap);
                city.put("count", num);
            }
        }
        return response.success(cityList);
    }

    /**
     * 根据区域编号获取河道数据
     * @param driverArea
     * @param type  1百度 2高德
     * @return
     */
    @Override
    public Response getDriversByDriverArea(Integer driverArea,Integer type) {
        if (StringUtils.isEmpty(driverArea)) {
            return response.failure("区域编号不存在");
        }
        Map<String,String> queryMap = new HashMap<>(3);
        queryMap.put("driverArea", driverArea.toString());
        queryMap.put("status", "3");
        queryMap.put("field", "inspect_driver_id,driver_name");
        List<TauvReport> reportList = iTauvReportService.getDataListByCond(queryMap);
        List<Map<String,Object>> result = new ArrayList<>();
        if (null != reportList) {

            for (TauvReport report : reportList) {
                Map<String,Object> resultMap = new HashMap<>(5);
                Integer inspectDriverId = report.getInspectDriverId();
                Integer questionNum = iTauvInspectFileService.getTotalFileByInspectDriverId(inspectDriverId);

                TauvInspectFile fileInfo = iTauvInspectFileService.getInfoByInspectDriverId(inspectDriverId);
                String longitude = "";
                String latitude = "";
                if (!StringUtils.isEmpty(fileInfo)) {
                    if (type.equals(2)) {
                        longitude = fileInfo.getGaodeLongitude();
                        latitude = fileInfo.getGaodeLatitude();
                    } else {
                        longitude = fileInfo.getBaiduLongitude();
                        latitude = fileInfo.getBaiduLatitude();
                    }

                }
                resultMap.put("code", inspectDriverId);
                resultMap.put("name", report.getDriverName());
                resultMap.put("longitude", longitude);
                resultMap.put("latitude", latitude);
                resultMap.put("count", questionNum);
                result.add(resultMap);
            }
        }
        return  response.success(result);
    }

    /**
     * 根据河道任务编号获取图片数据
     * @param inspectDriverId
     * @param type  1百度 2高德
     * @return
     */
    @Override
    public Response getFileListByInspectDriverId(Integer inspectDriverId, Integer type) {
        List<Map<String,Object>> dataList = new ArrayList<>();
        List<TauvInspectFile> fileList = iTauvInspectFileService.getListByInspectDriverId(inspectDriverId);
        if (!StringUtils.isEmpty(fileList)) {
            for(TauvInspectFile file : fileList) {
                Map<String,Object> infoMap = new HashMap<>(6);
                infoMap.put("name", file.getDescription());
                infoMap.put("code", "");

                if (type.equals(2)) {
                    infoMap.put("longitude", file.getGaodeLongitude());
                    infoMap.put("latitude", file.getGaodeLatitude());
                    infoMap.put("location", file.getGaodeAddress());
                } else {
                    infoMap.put("longitude", file.getBaiduLongitude());
                    infoMap.put("latitude", file.getBaiduLatitude());
                    infoMap.put("location", file.getBaiduAddress());
                }

                infoMap.put("num", 0);
                infoMap.put("imageUrl", uploadUrl + file.getOriginalImg());
                dataList.add(infoMap);
            }
        }
        return response.success(dataList);
    }
}
