package com.taauav.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.taauav.common.bean.Response;
import com.taauav.admin.entity.SysAdmin;
import com.taauav.admin.entity.SysAuthGroup;
import com.taauav.admin.entity.SysAuthGroupAccess;
import com.taauav.admin.entity.SysConfig;
import com.taauav.admin.mapper.SysAuthGroupMapper;
import com.taauav.admin.service.ISysAdminService;
import com.taauav.admin.service.ISysAuthGroupAccessService;
import com.taauav.admin.service.ISysAuthGroupService;
import com.taauav.admin.service.ISysConfigService;
import com.taauav.common.service.impl.BaseServiceImpl;
import com.taauav.common.util.DateUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.*;

/**
 * <p>
 * 用户组表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-04
 */
@Service
public class SysAuthGroupServiceImpl extends BaseServiceImpl<SysAuthGroupMapper, SysAuthGroup> implements ISysAuthGroupService {
    @Resource
    private SysAuthGroupMapper authGroupMapper;
    @Resource
    private Response response;
    @Autowired
    private ISysAuthGroupAccessService iSysAuthGroupAccessService;
    @Autowired
    private ISysAdminService iSysAdminService;
    @Autowired
    private ISysConfigService configService;

    /**
     * 根据用户编号获取权限
     *
     * @param adminId
     * @return
     */
    @Override
    public List<SysAuthGroup> getAuthGroups(Integer adminId) {

        return authGroupMapper.getAuthGroups(adminId);
    }

    @Override
    public List<Map<String, String>> getListByPid(Integer pid) {
        return authGroupMapper.getListByPid(pid);
    }

    /**
     * 根据角色值获取对应角色名称
     *
     * @param authGroup
     * @return
     */
    public String getAuthText(Integer authGroup) {
        String authText = "";
        SysAuthGroup auth = authGroupMapper.selectById(authGroup);
        if (auth != null) {
            if (auth.getPid() > 0) {
                SysAuthGroup pAuth = authGroupMapper.selectById(auth.getPid());
                if (pAuth != null) {
                    authText += pAuth.getName() + "-";
                }
            }
            authText += auth.getName();
        }
        return authText;
    }

    /**
     * 根据id获取数据
     *
     * @param id
     * @return
     */
    @Override
    public SysAuthGroup getInfoById(Integer id) {
        SysAuthGroup info = authGroupMapper.selectById(id);
        return info;
    }

    /**
     * 根据名称获取数据
     *
     * @param name
     * @return
     */
    @Override
    public SysAuthGroup getInfoByName(String name) {
        QueryWrapper<SysAuthGroup> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("name", name);
        queryWrapper.eq("mark", Byte.valueOf("1"));
        queryWrapper.last("limit 1");
        SysAuthGroup info = authGroupMapper.selectOne(queryWrapper);
        return info;
    }

    /**
     * 获取当前用户角色 1 内部用户 2外部用户
     *
     * @return
     */
    @Override
    public Integer getAuthGroupPid() {
        SysAdmin adminInfo = ShiroUtils.getAdminInfo();
        Integer authGroupId = Integer.valueOf(adminInfo.getAuthGroup());
        SysAuthGroup group = getInfoById(authGroupId);
        return StringUtils.isEmpty(group) ? 0 : group.getPid();
    }

    /**
     * 获取所有角色列表
     *
     * @param map
     * @return
     */
    @Override
    public Response getList(Map<String, String> map) {
        QueryWrapper<SysAuthGroup> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mark", Byte.valueOf("1"));
        queryWrapper.eq("pid", 0);
        queryWrapper.orderByAsc("id");
        queryWrapper.select("id,name,pid,has_child,rules,remark,status,sort,create_time,create_user");
        List<Map<String, Object>> list = authGroupMapper.selectMaps(queryWrapper);
        if (list != null) {
            for (Map<String, Object> sysAuthGroup : list) {
                queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("mark", Byte.valueOf("1"));
                queryWrapper.eq("pid", sysAuthGroup.get("id"));
                queryWrapper.orderByAsc("id");
                queryWrapper.select("id,name,pid,has_child,rules,remark,status,sort,create_time,create_user");
                sysAuthGroup = formatInfo(sysAuthGroup);
                List<Map<String, Object>> child = authGroupMapper.selectMaps(queryWrapper);
                if (child != null) {
                    for (Map<String, Object> childInfo : child) {
                        childInfo = formatInfo(childInfo);
                    }
                }
                sysAuthGroup.put("children", child);
            }
        }
        return response.success(list);
    }

    /**
     * 添加角色
     *
     * @param authGroup
     * @return
     */
    @Override
    public Response add(SysAuthGroup authGroup) {
        SysAuthGroup exit = getInfoByName(authGroup.getName());
        if (!StringUtils.isEmpty(exit)) {
            return response.failure("角色名称已经存在");
        }
        Integer adminId = ShiroUtils.getAdminId();
        authGroup.setCreateTime(DateUtil.now());
        authGroup.setCreateUser(adminId);
        Integer id = authGroupMapper.insert(authGroup);
        return response.success("操作成功", id);
    }

    /**
     * 修改角色
     *
     * @param authGroup
     * @return
     */
    @Override
    public Response edit(SysAuthGroup authGroup) {
        Integer id = authGroup.getId();
        if (StringUtils.isEmpty(id)) {
            return response.failure("数据不存在");
        }
        SysAuthGroup info = getInfoById(id);
        if (info == null) {
            return response.failure("数据不存在");
        }
        if (!(authGroup.getName().equals(info.getName()))) {
            SysAuthGroup exist = getInfoByName(authGroup.getName());
            if (!StringUtils.isEmpty(exist)) {
                return response.failure("角色名称已经存在");
            }
        }
        Integer res = authGroupMapper.updateById(authGroup);
        return response.success("操作成功", res);
    }

    /**
     * 删除角色
     *
     * @param authGroup
     * @return
     */
    @Override
    public Response del(SysAuthGroup authGroup) {
        Integer id = authGroup.getId();
        if (StringUtils.isEmpty(id)) {
            return response.failure("数据不存在");
        }
        SysAuthGroup info = getInfoById(id);
        if (info == null) {
            return response.failure("数据不存在");
        }
        //判断改角色下面是否存在用户
        List<SysAuthGroupAccess> groupAccesses = iSysAuthGroupAccessService.getListByGroupid(id);
        if (!groupAccesses.isEmpty()) {
            return response.failure("该角色已经关联用户，不能删除");
        }
        SysAuthGroup delSet = new SysAuthGroup();
        delSet.setId(authGroup.getId());
        delSet.setMark(0);
        Integer res = authGroupMapper.updateById(delSet);
        return response.success("操作成功", res);
    }

    /**
     * 设置角色权限
     *
     * @param map
     * @return
     */
    @Override
    public Response setRules(Map<String, String> map) {
        String ruleParam = map.get("rules");
        if (StringUtils.isEmpty(ruleParam)) {
            return response.failure("请选择权限");
        }
        String[] rules = ruleParam.split(",");
        Set<String> set = new TreeSet<>();
        for (String rule : rules) {
            set.add(rule);
        }
        String ruleStr = org.apache.commons.lang3.StringUtils.join(set.toArray(), ",");
        String idStr = (String) map.get("id");
        if (StringUtils.isEmpty(idStr)) {
            return response.failure("请选择角色");
        }
        Integer id = Integer.valueOf(idStr);
        SysAuthGroup info = getInfoById(id);
        if (StringUtils.isEmpty(info)) {
            return response.failure("请选择角色");
        }
        SysAuthGroup authGroup = new SysAuthGroup();
        authGroup.setId(id);
        authGroup.setRules(ruleStr);
        authGroupMapper.updateById(authGroup);
        //重置角色对应用户权限
        List<Map<String, Object>> adminList = iSysAdminService.getAdminListByGroupId(id);
        if (adminList != null) {
            for (Map<String, Object> admin : adminList) {
                String username = (String) admin.get("username");
                ShiroUtils.deleteCache(username, false);
            }
        }
        return response.success("操作成功");
    }

    /**
     * 修改菜单状态
     *
     * @param map
     * @return
     */
    @Override
    public Response editStatus(Map<String, String> map) {
        String idStr = map.get("id");
        String status = map.get("status");
        if (StringUtils.isEmpty(idStr)) {
            return response.failure("数据不存在");
        }
        if ("2".equals(status) || "1".equals(status)) {
            SysAuthGroup sysAuthGroup = new SysAuthGroup();
            sysAuthGroup.setId(Integer.valueOf(idStr));
            sysAuthGroup.setStatus(Integer.valueOf(status));
            authGroupMapper.updateById(sysAuthGroup);
            return response.success("操作成功");
        } else {
            return response.failure("状态不合法");
        }
    }

    /**
     * 格式化输出内容
     *
     * @param map
     * @return
     */
    private Map<String, Object> formatInfo(Map<String, Object> map) {
        String createTime = map.get("create_time").toString();
        String status = map.get("status").toString();
        map.put("format_create_time", createTime);
        String statusText = "1".equals(status) ? "正常" : "禁用";
        map.put("status_text", statusText);
        map.put("format_create_user", "");
        if (!StringUtils.isEmpty(map.get("create_user"))) {
            Integer createUser = Integer.valueOf(map.get("create_user").toString());
            SysAdmin adminInfo = iSysAdminService.getById(createUser);
            map.put("format_create_user", StringUtils.isEmpty(adminInfo) ? "" : adminInfo.getRealname());
        }

        //格式化权限
        String str = "rules";
        String[] ruleList = new String[0];
        if (!"".equals(map.get(str))) {
            ruleList = map.get(str).toString().split(",");
        }
        map.put("ruleList", ruleList);
        return map;
    }

    /**
     * 判断用户是否有飞行小组角色
     *
     * @param admin
     * @return
     */
    @Override
    public Boolean isFlightGroup(SysAdmin admin) {
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("mark", 1);
        wrapper.eq("name", "flight_auth_group");
        wrapper.eq("status", 1);
        SysConfig config = configService.getOne(wrapper);
        if (config != null) {
            String[] authGroup = admin.getAuthGroup().split(",");
            Boolean flag = false;
            if (authGroup != null) {
                for (String item : authGroup) {
                    if (item.equals(config.getValue())) {
                        flag = true;
                        break;
                    }
                }
            }
            return flag;
        } else {
            return false;
        }
    }
}
