package com.taauav.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.taauav.admin.dto.TauvInspectDriverAssignTaskDTO;
import com.taauav.admin.vo.TauvInspectDriverListVo;
import com.taauav.common.bean.Response;
import com.taauav.admin.dto.TauvInspectDriverDTO;
import com.taauav.admin.entity.*;
import com.taauav.admin.mapper.TauvInspectDriverMapper;
import com.taauav.admin.mapper.TauvInspectMapper;
import com.taauav.admin.service.*;
import com.taauav.common.service.impl.BaseServiceImpl;
import com.taauav.common.util.DateUtil;
import com.taauav.common.util.FileUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import com.taauav.admin.validate.ExecuteTask;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.io.File;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * <p>
 * 巡检任务河道表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-14
 */
@Service
@Slf4j
public class TauvInspectDriverServiceImpl extends BaseServiceImpl<TauvInspectDriverMapper, TauvInspectDriver> implements ITauvInspectDriverService {
    @Value("${spring.pageSize}")
    private Integer pageSize;
    @Value("${server.UPLOAD_URL}")
    private String uploadUrl;
    @Value("${file.uploadFolder}")
    private String uploadFolder;
    @Autowired
    private TauvInspectDriverMapper inspectDriverMapper;
    @Autowired
    private ITauvDriverService iTauvDriverService;
    @Autowired
    private ISysAdminService iSysAdminService;
    @Autowired
    private ISysCityService iSysCityService;
    @Autowired
    private Response response;
    @Autowired
    private ITauvReportService iTauvReportService;
    //为了避免相互依赖 这里直接引用Inspect的DAO接口类，没有引用对应的业务service接口
    @Autowired
    private TauvInspectMapper inspectMapper;
    private QueryWrapper wrapper;

    /**
     * 添加巡检任务
     *
     * @param inspect
     */
    @Override
    public String batchAddData(TauvInspect inspect) {
        List<TauvInspectDriver> inspectDriver = inspect.getInspectDriverList();
        Integer inspectId = inspect.getId();
        String errorMsg = "";
        if (inspectDriver != null && !"".equals(inspectDriver) && inspectDriver.size() > 0) {
            int i = 1;
            for (TauvInspectDriver driver : inspectDriver) {
//                if (!StringUtils.isEmpty(driver.getDriverImage())) {
//                    //如果上传了图片 对图片做处理
//                    String img = driver.getDriverImage();
//                    if (img.contains("temp")) {
//                        img = img.replace(uploadUrl, uploadFolder);
//                        File oldFile = new File(img);
//                        if (!oldFile.exists()) {
//                            return "图片不存在";
//                        }
//                        String fileName = oldFile.getName();
//                        if (fileName.contains("thumbnail")) {
//                            fileName = fileName.replace("-thumbnail", "");
//                        }
//                        //把文件移动到正式目录下
//                        Calendar date = Calendar.getInstance();
//                        String year = String.valueOf(date.get(Calendar.YEAR));
//                        String month = String.valueOf(date.get(Calendar.MONTH) + 1);
//                        String day = String.valueOf(date.get(Calendar.DATE));
//                        String destImg = uploadFolder + "file/file/" + year + "/" + month + "/" + day + "/";
//                        boolean flag = FileUtil.cutGeneralFile(img, destImg);
//                        if (flag) {
//                            destImg = destImg.replace(uploadFolder, "");
//                            driver.setDriverImage(destImg + fileName);
//                        } else {
//                            return "图片保存失败了!";
//                        }
//                    }
//                }
                if (!StringUtils.isEmpty(driver.getDriverFile())) {
                    // 如果上传了文件则对文件进行处理
                    String file = driver.getDriverFile();
                    if (file.contains("temp")) {
                        file = file.replace(uploadUrl, uploadFolder);
                        File oldFile = new File(file);
                        if (!oldFile.exists()) {
                            return "文件不存在";
                        }
                        //把文件移动到正式目录下
                        Calendar date = Calendar.getInstance();
                        String year = String.valueOf(date.get(Calendar.YEAR));
                        String month = String.valueOf(date.get(Calendar.MONTH) + 1);
                        String day = String.valueOf(date.get(Calendar.DATE));
                        String destFile = uploadFolder + "file/file/" + year + "/" + month + "/" + day + "/";
                        boolean flag = FileUtil.cutGeneralFile(file, destFile);
                        if (flag) {
                            // 文件名
                            String fileName = oldFile.getName();
                            destFile = destFile.replace(uploadFolder, "");
                            driver.setDriverFile(destFile + fileName);
                        } else {
                            return "图片保存失败了!";
                        }
                    }
                }
                Integer driverId = driver.getDriverId();
                TauvDriver driverInfo = iTauvDriverService.getInfoById(driverId);
                if (driverInfo != null) {
                    driver.setDriverName(driverInfo.getName());
                    driver.setDriverArea(driverInfo.getDriverArea());
                    BigDecimal bigDecimal = new BigDecimal(driverInfo.getLength());
                    driver.setDriverLength(bigDecimal);
                    driver.setDriverStart(driverInfo.getStartPoint());
                    driver.setDriverEnd(driverInfo.getEndPoint());
//                    driver.setDriverExam(driverInfo.getIsExam());
                } else {
                    //抛出异常
                    return "河流名称不存在";
                }
                driver.setInspectId(inspectId);
                driver.setInspectNo(inspect.getInspectNo());
                driver.setCreateTime(DateUtil.now());
                driver.setCreateUser(ShiroUtils.getAdminId());
                driver.setNum(i * 10);
                i++;
            }
        } else {
            return "请选择河流信息";
        }
        saveBatch(inspectDriver);
        return errorMsg;
    }

    /**
     * 巡检任务分页数据列表
     *
     * @param map
     * @param act
     * @return
     */
    @Override
    public Response getPageList(Map<String, Object> map, String act) {
        Integer pageNo = 1;
        if (!StringUtils.isEmpty(map)) {
            if (map.containsKey("page") && !"".equals(map.get("page")) && Integer.valueOf(map.get("page").toString()) > 0) {
                pageNo = Integer.valueOf(map.get("page").toString());
            }
            //每页数量
            if (map.containsKey("pageSize") && !"".equals(map.get("pageSize")) && Integer.valueOf(map.get("pageSize").toString()) > 0) {
                pageSize = Integer.valueOf(map.get("pageSize").toString());
            }
            //分配列表：期望巡检时间 任务列表：执行时间
            String inspectTime = "inspectTime";
            if (!StringUtils.isEmpty(map.get(inspectTime))) {
                String startTime = FunctionUtils.formatTime(Integer.valueOf(map.get(inspectTime).toString()), "yyyy-MM-dd") + " 00:00:00";
                Integer startStamp = FunctionUtils.dateToStamp(startTime);
                if ("list".equals(act)) {
                    map.put("executionTime", startStamp);
                    map.remove("inspectTime");
                } else {
                    map.put("inspectTime", startStamp);
                    map.remove("executionTime");
                }
            }
//            //河道类型
//            String driverExam = "driverExam";
//            if (!StringUtils.isEmpty(map.get(driverExam)) && Integer.valueOf(map.get(driverExam).toString()) > 0) {
//                map.put("driverExam", Integer.valueOf(map.get(driverExam).toString()));
//            } else {
//                map.remove(driverExam);
//            }
            //区属
            map = FunctionUtils.dealArea(map);
        } else {
            map = new HashMap<>();
        }

        Page<TauvInspectDriverDTO> page = new Page<>(pageNo, pageSize);
        List<TauvInspectDriverDTO> data = inspectDriverMapper.getPageList(page, map);

        TauvInspect tauvInspect = new TauvInspect();
        if (data != null) {
            for (TauvInspectDriverDTO driver : data) {
                driver = getInfoDetail(driver);
            }
        }
        page.setRecords(data);
        return response.success(page);
    }

    /**
     * 根据编号获取数据
     *
     * @param id
     * @return
     */
    @Override
    public TauvInspectDriver getInfoById(Integer id) {
        return inspectDriverMapper.selectById(id);
    }

    /**
     * 获取待分配任务ID集合
     *
     * @param inspectDriverIds 待分配任务ID(多个逗号","分隔)
     * @return
     */
    @Override
    public Response getAssignTaskList(String inspectDriverIds) {
        // 查询条件
        QueryWrapper<TauvInspectDriver> queryWrapper = new QueryWrapper<>();
        // 待分配任务
        String arr[] = inspectDriverIds.split(",");
        ArrayList arrayList = new ArrayList();
        for (String s : arr) {
            arrayList.add(s);
        }
        queryWrapper.in("id", arrayList);
        queryWrapper.eq("mark", 1);

        // 查询数据
        List<TauvInspectDriver> inspectDriverList = inspectDriverMapper.selectList(queryWrapper);
        List<TauvInspectDriverListVo> inspectDriverListVoList = new ArrayList<>();
        List<String> inspectTypeList = new ArrayList<>();
        if (!inspectDriverList.isEmpty()) {
            inspectDriverList.forEach(item -> {
                TauvInspectDriverListVo inspectDriverListVo = new TauvInspectDriverListVo();
                // 拷贝属性
                BeanUtils.copyProperties(item, inspectDriverListVo);
                // 区划
                String cityName = iSysCityService.getCityName(item.getDriverArea());
                inspectDriverListVo.setDriverAreaName(cityName);
                // 图片地址
                inspectDriverListVo.setDriverFile(uploadUrl + inspectDriverListVo.getDriverFile());
                // 巡检时间
                TauvInspect inspectInfo = inspectMapper.selectById(item.getInspectId());
                if (inspectInfo != null) {
                    inspectDriverListVo.setInspectTime(inspectInfo.getInspectTime());
                    String inspectType = inspectInfo.getTypeList().get(inspectInfo.getType());
                    if (!inspectTypeList.contains(inspectType)) {
                        inspectTypeList.add(inspectType);
                    }
                }
                inspectDriverListVoList.add(inspectDriverListVo);
            });
        }

        // 返回结果
        Map<String, Object> result = new HashMap<>();
        result.put("inspectTypeList", inspectTypeList);
        result.put("inspectDriverList", inspectDriverListVoList);
        return response.success(result);
    }

    /**
     * 分配任务
     *
     * @param assignTaskDto
     * @return
     */
    @Override
    public Response assignTask(TauvInspectDriverAssignTaskDTO assignTaskDto) {
        // 验证河流是否为空
        if (assignTaskDto.getInspectDrivers() == null) {
            return response.failure("河流信息不存在");
        }
        // 执行时间
        if (assignTaskDto.getExecutionTime() == null) {
            return response.failure("执行时间不能为空");
        }
        // 无人机设备校验
        if (assignTaskDto.getEquipmentId() == null || assignTaskDto.getEquipmentId() <= 0) {
            return response.failure("无人机设备不能为空");
        }
        // 挂载设备
        if (assignTaskDto.getMountequipmentId() == null || assignTaskDto.getMountequipmentId() <= 0) {
            return response.failure("挂载设备不能为空");
        }
        // 飞手校验
        if (assignTaskDto.getAdminId() == null || assignTaskDto.getAdminId() <= 0) {
            return response.failure("飞手不能为空");
        }
        // 循环遍历河流信息
        Integer totalNum = 0;
        for (TauvInspectDriver inspectDriver : assignTaskDto.getInspectDrivers()) {
            if (inspectDriver.getId() == null || inspectDriver.getId() <= 0) {
                continue;
            }
            // 执行时间
            inspectDriver.setExecutionTime(assignTaskDto.getExecutionTime());
            // 无人机设备
            inspectDriver.setEquipmentId(assignTaskDto.getEquipmentId());
            // 挂载设备
            inspectDriver.setMountequipmentId(assignTaskDto.getMountequipmentId());
            // 飞手
            inspectDriver.setFlightHand(assignTaskDto.getAdminId());
            // 设置已分配状态
            inspectDriver.setStatus(2);
            // 更新巡检河流信息
            boolean result = this.editData(inspectDriver);
            if (result) {
                totalNum++;
            }
        }
        if (totalNum == assignTaskDto.getInspectDrivers().size()) {
            return response.success("任务分配成功");
        }
        return response.failure("任务分配失败");
    }

//    /**
//     * 分配任务
//     *
//     * @param map
//     * @return
//     */
//
//    @Override
//    public Response assignTask(Map<String, String> map) {
//        if (StringUtils.isEmpty(map)) {
//            return response.failure("请求参数不能为空");
//        }
//        String adminIdStr = map.getOrDefault("adminId", "");
//        if (StringUtils.isEmpty(adminIdStr)) {
//            return response.failure("请选择分配的飞行小组");
//        }
//        String ids = map.getOrDefault("ids", "");
//        if (StringUtils.isEmpty(ids)) {
//            return response.failure("请选择要分配的任务");
//        }
//        Integer adminId = Integer.valueOf(adminIdStr);
//        SysAdmin adminInfo = iSysAdminService.getAdminInfo(adminId);
//        if (StringUtils.isEmpty(adminInfo)) {
//            return response.failure("飞行小组不存在");
//        }
//        String[] idsArr = ids.split(",");
//        String msg = "";
//        for (String idStr : idsArr) {
//            Integer id = Integer.valueOf(idStr);
//            TauvInspectDriver info = getInfoById(id);
//            if (StringUtils.isEmpty(info)) {
//                msg = "编号" + id + "数据不存在";
//                break;
//            }
//
//            Boolean f = assignFlightGroup(id, adminId);
//            if (!f) {
//                msg = "分配失败";
//                break;
//            }
//        }
//        if (StringUtils.isEmpty(msg)) {
//            return response.success("操作成功");
//        } else {
//            return response.failure("操作失败");
//        }
//    }

//    /**
//     * 分配飞行小组
//     *
//     * @param id
//     * @param flightGroupId
//     * @return
//     */
//    @Override
//    public boolean assignFlightGroup(Integer id, Integer flightGroupId) {
//        TauvInspectDriver inspectDriver = new TauvInspectDriver();
//        inspectDriver.setId(id);
//        inspectDriver.setFlightHand(flightGroupId);
//        inspectDriver.setStatus(Integer.valueOf("2"));
//        Integer res = inspectDriverMapper.updateById(inspectDriver);
//        if (res > 0) {
//            return true;
//        } else {
//            return false;
//        }
//    }

    /**
     * 详情
     *
     * @param id
     * @return
     */
    @Override
    public Map<String, Object> detail(Integer id) {
        Map<String, Object> detail = new HashMap<>();
        if (StringUtils.isEmpty(id)) {
            detail.put("error", "参数不存在");
            return detail;
        }
        TauvInspectDriver info = getInfoById(id);
        if (StringUtils.isEmpty(info)) {
            detail.put("error", "数据不存在");
            return detail;
        }
        Integer inspectId = info.getInspectId();
        if (StringUtils.isEmpty(inspectId)) {
            detail.put("error", "任务编号不存在");
            return detail;
        }
        TauvInspect inspectInfo = inspectMapper.selectById(inspectId);

        BigInteger driverArea = info.getDriverArea();
        detail.put("id", info.getId());
        detail.put("inspectNo", info.getInspectNo());
        detail.put("num", info.getNum());
        detail.put("driverName", info.getDriverName());
        if (StringUtils.isEmpty(driverArea)) {
            detail.put("driverArea", "");
        } else {
//            SysCity cityInfo = iSysCityService.getInfoById(driverArea);
//            detail.put("driverArea", StringUtils.isEmpty(cityInfo) ? "" : cityInfo.getName());
            String cityName = iSysCityService.getCityName(driverArea);
            detail.put("driverArea", cityName);
        }

//        detail.put("executionTime", executionTime);
        detail.put("driverStart", info.getDriverStart());
        detail.put("driverEnd", info.getDriverEnd());
        detail.put("driverLength", info.getDriverLength());
        detail.put("weather", info.getWeather());
        detail.put("wind", info.getWind());
        detail.put("temperature", info.getTemperature());
        detail.put("flightTime", info.getFlightTime());
        detail.put("flightHeight", info.getFlightHeight());
        detail.put("flightSpeed", info.getFlightSpeed());
        detail.put("flightGroup", info.getFlightHand());
        // 巡检时间
        String inspectTime = "";
        if (!StringUtils.isEmpty(inspectInfo.getInspectTime())) {
            inspectTime = DateUtil.format(inspectInfo.getInspectTime(), "yyyy-MM-dd HH:mm:ss");
        }
        detail.put("inspectTime", inspectTime);
//        detail.put("inspectTime", inspectInfo.getInspectTime());
//        //图片位置信息
//        if (!"".equals(info.getDriverImage())) {
//            info.setDriverImage(uploadUrl + info.getDriverImage());
//        }
//        detail.put("driverImage", info.getDriverImage());
//        //巡检目的
//        detail.put("inspectPurpose", inspectInfo.getInspectPurpose());
//        //巡检结果
//        detail.put("inspectResult", inspectInfo.getInspectResult());
        // 备注
        detail.put("note", inspectInfo.getNote());
        //执行时间
        String executionTime = "";
        if (info.getExecutionTime() != null) {
            executionTime = DateUtil.format(info.getExecutionTime(), "yyyy-MM-dd HH:mm:ss");
        }
        detail.put("executionTime", executionTime);
        return detail;
    }

    /**
     * 取消
     *
     * @param map
     * @return
     */
    @Override
    public Response cancel(Map<String, String> map) {
        if (StringUtils.isEmpty(map)) {
            return response.failure("参数不存在");
        }
        Integer id = Integer.valueOf(map.getOrDefault("id", ""));
        TauvInspectDriver info = getInfoById(id);
        if (StringUtils.isEmpty(info)) {
            return response.failure("数据不存在");
        }
        String status = info.getStatus().toString();
        String needStatus = "2";
        if (!(needStatus.equals(status))) {
            return response.failure("当前状态不可取消");
        }
        TauvInspectDriver inspectDriver = new TauvInspectDriver();
        inspectDriver.setId(id);
        inspectDriver.setStatus(Integer.valueOf("1"));
        inspectDriverMapper.updateById(inspectDriver);
        return response.success("操作成功");
    }

    /**
     * 执行任务
     *
     * @param task
     * @return
     */
    @Override
    public Response executeTask(ExecuteTask task) {
//        String executionTime = task.getExecutionTime();
        Integer id = Integer.valueOf(task.getId());
        Integer adminId = ShiroUtils.getAdminId();
        TauvInspectDriver info = getInfoById(id);
        if (StringUtils.isEmpty(info)) {
            return response.failure("数据不存在");
        }
        Integer fligGroup = info.getFlightHand();
        if (!fligGroup.equals(adminId) && !fligGroup.equals(1)) {
            response.failure("只有被分配的小组才有权限");
        }
        TauvInspectDriver inspectDriver = new TauvInspectDriver();
//        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

        inspectDriver.setWeather(task.getWeather());
        inspectDriver.setWind(task.getWind());
        inspectDriver.setTemperature(task.getTemperature());
        inspectDriver.setFlightHeight(new BigDecimal(task.getFlightHeight()));
        inspectDriver.setFlightSpeed(new BigDecimal(task.getFlightSpeed()));
        inspectDriver.setFlightTime(new BigDecimal(task.getFlightTime()));
        inspectDriver.setRemark(task.getRemark());
        inspectDriver.setStatus(3);
        inspectDriver.setFlightHand(adminId);
        inspectDriver.setExecutionTime(task.getExecutionTime());
        inspectDriver.setId(id);
        inspectDriverMapper.updateById(inspectDriver);
        return response.success("执行成功");
    }

    /**
     * 获取打印数据的基本信息
     *
     * @param id
     * @return
     */
    @Override
    public Response getPrintData(Integer id) {
        Map<String, Object> info = detail(id);
        if (!StringUtils.isEmpty(info.get("error"))) {
            return response.failure(info.get("error"));
        }
        Integer groupId = (Integer) info.get("flightGroup");
        Long startTime = new Long(info.get("executionStartTime").toString());
        Long inspectTime = new Long(info.get("inspectTime").toString());
        if (startTime > 0) {
            info.put("executionTime", FunctionUtils.formatTime(startTime.intValue(), "yyyy-MM-dd HH:mm:ss"));
        } else {
            info.put("executionTime", "");
        }
        if (inspectTime > 0) {
            info.put("formatinspectTime", FunctionUtils.formatTime(inspectTime.intValue(), "yyyy-MM-dd HH:mm:ss"));
        } else {
            info.put("formatinspectTime", "");
        }
        SysAdmin adminInfo = iSysAdminService.getAdminInfo(groupId);
        info.put("flightGroupText", StringUtils.isEmpty(adminInfo) ? "" : adminInfo.getRealname());
        return response.success(info);
    }

    /**
     * 获取数据详细数据
     *
     * @param driver
     * @return
     */
    private TauvInspectDriverDTO getInfoDetail(TauvInspectDriverDTO driver) {
        TauvInspect tauvInspect = new TauvInspect();
        Map<Integer, String> mapList = driver.getStatusList();
        Map<Integer, String> typeList = tauvInspect.getTypeList();

        if (StringUtils.isEmpty(driver.getType())) {
            driver.setTypeText("");
        } else {
            driver.setTypeText(typeList.get(driver.getType().intValue()));
        }

        driver.setStatusText(mapList.get(driver.getStatus().intValue()));

        SysAdmin adminInfo = iSysAdminService.getAdminInfo(driver.getCreateUser());
        driver.setFormatCreateUser(StringUtils.isEmpty(adminInfo) ? "" : adminInfo.getRealname());
//        driver.setFormatCreateTime(FunctionUtils.formatTime(driver.getCreateTime(), "yyyy-MM-dd HH:mm:ss"));
//        driver.setFormatinspectTime(FunctionUtils.formatTime(driver.getinspectTime(), "yyyy-MM-dd HH:mm:ss"));
//        driver.setFormatInspectEndTime(FunctionUtils.formatTime(driver.getInspectEndTime(), "yyyy-MM-dd HH:mm:ss"));
//        driver.setFormatExecutionStartTime(FunctionUtils.formatTime(driver.getExecutionStartTime(), "yyyy-MM-dd HH:mm:ss"));
//        driver.setFormatExecutionEndTime(FunctionUtils.formatTime(driver.getExecutionEndTime(), "yyyy-MM-dd HH:mm:ss"));
        driver.setFormatCreateTime(DateUtil.format(driver.getCreateTime(), "yyyy-MM-dd HH:mm:ss"));
        driver.setFormatInspectTime(DateUtil.format(driver.getInspectTime(), "yyyy-MM-dd HH:mm:ss"));
        if (!StringUtils.isEmpty(driver.getExecutionStartTime())) {
            driver.setFormatExecutionStartTime(DateUtil.format(driver.getExecutionStartTime(), "yyyy-MM-dd HH:mm:ss"));
        }
        if (!StringUtils.isEmpty(driver.getExecutionEndTime())) {
            driver.setFormatExecutionEndTime(DateUtil.format(driver.getExecutionEndTime(), "yyyy-MM-dd HH:mm:ss"));
        }
        if (!StringUtils.isEmpty(driver.getDriverArea())) {
            SysCity cityInfo = iSysCityService.getInfoById(driver.getDriverArea());
            driver.setDriverAreaText(StringUtils.isEmpty(cityInfo) ? "" : cityInfo.getName());
        } else {
            driver.setDriverAreaText("");
        }
        //已完成时展示报告
        if (driver.getStatus() == 4) {
            wrapper = new QueryWrapper();
            wrapper.eq("mark", 1);
            wrapper.eq("inspect_driver_id", driver.getId());
            TauvReport report = iTauvReportService.getOne(wrapper);
            if (report != null) {
                driver.setReportId(report.getId());
            }
        }
        return driver;
    }

    /**
     * 判断任务是否已生成报告
     *
     * @param map
     * @return
     * @description
     */
    @Override
    public Response existReport(Map<String, Object> map) {
        if (StringUtils.isEmpty(map)) {
            return response.failure("参数不能为空");
        }
        String idStr = "id";
        if (map.containsKey(idStr) && !"".equals(map.get(idStr)) && map.get(idStr) != null) {
            Integer id = Integer.valueOf(map.get(idStr).toString());
            if (id <= 0) {
                return response.failure("任务id不合法");
            }
            QueryWrapper wrp = new QueryWrapper();
            wrp.eq("id", id);
            wrp.eq("mark", 1);
            TauvInspectDriver info = inspectDriverMapper.selectOne(wrp);
            if (info == null) {
                return response.failure("任务数据不存在");
            }
            //校验任务对应的报告是否已生成
            QueryWrapper wrapper = new QueryWrapper();
            wrapper.eq("mark", 1);
            wrapper.eq("num", info.getNum());
            wrapper.eq("inspect_no", info.getInspectNo());
            wrapper.eq("inspect_driver_id", id);
            TauvReport reportInfo = iTauvReportService.getOne(wrapper);
            if (reportInfo != null) {
                return response.success(true);
            } else {
                return response.success(false);
            }
        } else {
            return response.failure("任务id不存在");
        }
    }

    /**
     * 删除任务
     *
     * @param map
     * @return
     * @description 校验任务是否已存在报告，如已存在，则不可删除
     */
    @Override
    public Response dropTask(Map<String, Object> map) {
        if (StringUtils.isEmpty(map)) {
            return response.failure("参数不能为空");
        }
        String idStr = "id";
        if (map.containsKey(idStr) && !"".equals(map.get(idStr)) && map.get(idStr) != null) {
            Integer id = Integer.valueOf(map.get(idStr).toString());
            if (id <= 0) {
                return response.failure("任务id不合法");
            }
            QueryWrapper wrp = new QueryWrapper();
            wrp.eq("id", id);
            wrp.eq("mark", 1);
            TauvInspectDriver info = inspectDriverMapper.selectOne(wrp);
            if (info == null) {
                return response.failure("任务数据不存在");
            }
            //校验任务对应的报告是否已生成
            QueryWrapper wrapper = new QueryWrapper();
            wrapper.eq("mark", 1);
            wrapper.eq("num", info.getNum());
            wrapper.eq("inspect_no", info.getInspectNo());
            wrapper.eq("inspect_driver_id", id);
            TauvReport reportInfo = iTauvReportService.getOne(wrapper);
            if (reportInfo != null) {
                return response.failure("该任务已经生成报告，请先删除报告后再处理。");
            }
            info.setMark(0);
            inspectDriverMapper.updateById(info);
            return response.success("操作成功");
        } else {
            return response.failure("任务id不存在");
        }
    }

    /**
     * 重处理任务
     *
     * @param map
     * @return
     */
    @Override
    public Response reProcess(Map<String, Object> map) {
        if (StringUtils.isEmpty(map)) {
            return response.failure("参数不能为空");
        }
        String idStr = "id";
        if (map.containsKey(idStr) && !"".equals(map.get(idStr)) && map.get(idStr) != null) {
            Integer id = Integer.valueOf(map.get(idStr).toString());
            if (id <= 0) {
                return response.failure("任务id不合法");
            }
            QueryWrapper wrp = new QueryWrapper();
            wrp.eq("id", id);
            wrp.eq("mark", 1);
            TauvInspectDriver info = inspectDriverMapper.selectOne(wrp);
            if (info == null) {
                return response.failure("任务数据不存在");
            }
            info.setStatus(Integer.valueOf("3"));
            inspectDriverMapper.updateById(info);
            return response.success("操作成功");
        } else {
            return response.failure("任务id不存在");
        }
    }
}
