package com.taauav.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.taauav.common.bean.Response;
import com.taauav.admin.entity.SysAdmin;
import com.taauav.admin.entity.TauvQuestionOptions;
import com.taauav.admin.mapper.TauvQuestionOptionsMapper;
import com.taauav.admin.service.ISysAdminService;
import com.taauav.admin.service.ITauvQuestionOptionsService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.taauav.common.service.impl.BaseServiceImpl;
import com.taauav.common.util.DateUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 问题选项管理表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-13
 */
@Service
public class TauvQuestionOptionsServiceImpl extends BaseServiceImpl<TauvQuestionOptionsMapper, TauvQuestionOptions> implements ITauvQuestionOptionsService {
    @Value("${spring.pageSize}")
    private Integer pageSize;
    @Autowired
    private Response response;
    @Autowired
    private TauvQuestionOptionsMapper questionOptionsMapper;
    @Autowired
    private ISysAdminService iSysAdminService;

    /**
     * 获取分页数据
     *
     * @param map
     * @return
     */
    @Override
    public Response getPageList(Map<String, String> map) {
        QueryWrapper<TauvQuestionOptions> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mark", 1);
        Integer pageNo = 1;
        if (map != null) {
            //每页数量
            String size = "pageSize";
            if (map.containsKey(size) && Integer.valueOf(map.get(size)) > 0) {
                pageSize = Integer.valueOf(map.get(size));
            }
            //页数
            String page = "page";
            if (map.containsKey(page) && !"".equals(map.get(page)) && Integer.valueOf(map.get(page)) > 0) {
                pageNo = Integer.valueOf(map.get("page"));
            }
        }
        queryWrapper.orderByAsc("status", "sort");
        IPage<TauvQuestionOptions> page = new Page<>(pageNo, pageSize);
        IPage<Map<String, Object>> data = questionOptionsMapper.selectMapsPage(page, queryWrapper);
        if (!StringUtils.isEmpty(data.getRecords())) {
            TauvQuestionOptions questionOptions = new TauvQuestionOptions();
            Map<Integer, String> statusList = questionOptions.getStatusList();
            Map<Integer, String> categoryList = questionOptions.getCategoryList();
            Map<Integer, String> typeList = questionOptions.getTypeList();
            for (Map<String, Object> dt : data.getRecords()) {
                if (StringUtils.isEmpty(dt.get("create_time"))) {
                    dt.put("format_create_time", "");
                } else {
                    String createTime = dt.get("create_time").toString();
                    dt.put("format_create_time", FunctionUtils.formatTime(Integer.valueOf(createTime), "yyyy-MM-dd HH:mm:ss"));
                }
                dt.put("format_create_user", "");
                if (!StringUtils.isEmpty(dt.get("create_user"))) {
                    Integer createUser = Integer.valueOf(dt.get("create_user").toString());
                    SysAdmin adminInfo = iSysAdminService.getById(createUser);
                    if (!StringUtils.isEmpty(adminInfo)) {
                        dt.put("format_create_user", adminInfo.getRealname());
                    }
                }
                dt.put("status_text", StringUtils.isEmpty(statusList.get(dt.get("status"))) ? "" : statusList.get(dt.get("status")));
                dt.put("category_text", StringUtils.isEmpty(categoryList.get(dt.get("category"))) ? "" : categoryList.get(dt.get("category")));
                dt.put("type_text", StringUtils.isEmpty(typeList.get(dt.get("type"))) ? "" : typeList.get(dt.get("type")));
            }
        }
        return response.success(data);
    }

    /**
     * 修改数据
     *
     * @param questionOptions
     * @return
     */
    @Override
    public Response edit(TauvQuestionOptions questionOptions) {
        questionOptions.setUpdateTime(DateUtil.now());
        questionOptions.setUpdateUser(ShiroUtils.getAdminId());
        questionOptionsMapper.updateById(questionOptions);
        return response.success("添加成功");
    }

    /**
     * 添加数据
     *
     * @param questionOptions
     * @return
     */
    @Override
    public Response add(TauvQuestionOptions questionOptions) {
        questionOptions.setCreateTime(DateUtil.now());
        questionOptions.setCreateUser(ShiroUtils.getAdminId());
        questionOptionsMapper.insert(questionOptions);
        return response.success("添加成功");
    }

    /**
     * 设置状态
     *
     * @param map
     * @return
     */
    @Override
    public Response setStatus(Map<String, String> map) {
        if (StringUtils.isEmpty(map)) {
            return response.failure("参数不能为空");
        }
        String idStr = map.getOrDefault("id", "");
        String statusStr = map.getOrDefault("status", "");
        if (StringUtils.isEmpty(idStr)) {
            return response.failure("编号不存在");
        }
        if (StringUtils.isEmpty(statusStr)) {
            return response.failure("状态不能为空");
        }
        if (!("1".equals(statusStr) || "2".equals(statusStr))) {
            return response.failure("状态值不合法");
        }
        Integer id = Integer.valueOf(idStr);
        if (StringUtils.isEmpty(getInfoById(id))) {
            return response.failure("数据不存在");
        }
        TauvQuestionOptions questionOptions = new TauvQuestionOptions();
        questionOptions.setId(Integer.valueOf(idStr));
        questionOptions.setStatus(Integer.valueOf(statusStr));
        questionOptionsMapper.updateById(questionOptions);
        return response.success("操作成功");
    }

    /**
     * 根据编号获取数据
     *
     * @param id
     * @return
     */
    @Override
    public TauvQuestionOptions getInfoById(Integer id) {
        if (StringUtils.isEmpty(id)) {
            return null;
        }
        return questionOptionsMapper.selectById(id);
    }

    /**
     * 分类和类型等数据
     *
     * @return
     */
    @Override
    public Map<String, Object> getBaseData() {
        TauvQuestionOptions questionOptions = new TauvQuestionOptions();
        Map<String, Object> map = new HashMap<>(2);
        map.put("type_list", questionOptions.getTypeList());
        map.put("category_list", questionOptions.getCategoryList());
        return map;
    }

    /**
     * 获取所有问题列表
     *
     * @return
     */
    @Override
    public List<TauvQuestionOptions> getDataList() {
        QueryWrapper<TauvQuestionOptions> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mark", 1);
        queryWrapper.eq("status", 1);
        queryWrapper.orderByAsc("sort");
        queryWrapper.orderByAsc("id");
        return questionOptionsMapper.selectList(queryWrapper);
    }
}
