package com.taauav.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.taauav.common.bean.Response;
import com.taauav.admin.dto.TauvReportDTO;
import com.taauav.admin.dto.TauvReportInputDTO;
import com.taauav.admin.entity.*;
import com.taauav.admin.mapper.TauvInspectDriverMapper;
import com.taauav.admin.mapper.TauvReportMapper;
import com.taauav.admin.service.*;
import com.taauav.common.service.impl.BaseServiceImpl;
import com.taauav.common.util.DateUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import org.apache.commons.beanutils.ConvertUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.time.LocalDateTime;
import java.util.*;

/**
 * <p>
 * 巡检报告表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-22
 */
@Service
public class TauvReportServiceImpl extends BaseServiceImpl<TauvReportMapper, TauvReport> implements ITauvReportService {
    @Autowired
    private TauvReportMapper reportMapper;
    @Autowired
    private TauvInspectDriverMapper inspectDriverMapper;
    @Autowired
    private ISysCityService iSysCityService;
    @Value("${spring.pageSize}")
    private Integer pageSize;
    @Value("${server.UPLOAD_URL}")
    private String uploadUrl;
    @Value("${server.IMAGE_URL}")
    private String imageUrl;
    @Autowired
    private Response response;
    @Autowired
    private ISysAdminService iSysAdminService;
    @Autowired
    private ISysAuthGroupService iSysAuthGroupService;
    @Autowired
    private ITauvQuestionOptionsService iTauvQuestionOptionsService;
    @Autowired
    private ITauvInspectFileService iTauvInspectFileService;
    @Autowired
    private ITauvReportRemarkService iTauvReportRemarkService;
    @Autowired
    private ITauvReportEvaluationService iTauvReportEvaluationService;
    @Autowired
    private ITauvReportCheckService iTauvReportCheckService;
    @Autowired
    private ITauvDriverService tauvDriverService;

    /**
     * 添加报告
     *
     * @param report
     */
    @Override
    public void addReport(TauvReport report) {
        reportMapper.insert(report);
    }

    /**
     * 根据任务编号获取数据
     *
     * @param inspectDriverId
     * @return
     */
    @Override
    public TauvReport getInfoByInspectDriverId(Integer inspectDriverId) {
        QueryWrapper<TauvReport> wrapper = new QueryWrapper<>();
        wrapper.eq("inspect_driver_id", inspectDriverId);
        wrapper.eq("mark", 1);
        wrapper.last("limit 1");
        return reportMapper.selectOne(wrapper);
    }

    /**
     * 报告待生成列表
     *
     * @param map
     * @return
     */
    @Override
    public Response getGenerateList(Map<String, Object> map) {
        if (StringUtils.isEmpty(map)) {
            map = new HashMap<>();
        }
        if (map.containsKey("status") && !"".equals(map.get("status")) && Integer.valueOf(map.get("status").toString()) > 0) {
            Integer[] status = {Integer.valueOf(map.get("status").toString())};
            map.put("status", status);
        } else {
            Integer[] status = {1, 4};
            map.put("status", status);
        }
        if (map.containsKey("driverArea") && !"".equals(map.get("driverArea"))) {
            map.put("driverArea", Integer.valueOf(map.get("driverArea").toString()));
        } else {
            map.remove("driverArea");
        }
        if (map.containsKey("driverName") && "".equals(map.get("driverName"))) {
            map.remove("driverName");
        }
        if (map.containsKey("inspectStartTime") && !"".equals(map.get("inspectStartTime")) && Integer.valueOf(map.get("inspectStartTime").toString()) > 0) {
            String endTime = FunctionUtils.formatTime(Integer.valueOf(map.get("inspectStartTime").toString()), "yyyy-MM-dd") + " 23:59:59";
            Integer endStamp = FunctionUtils.dateToStamp(endTime);
            map.put("endTime", endStamp);
        }
        //河道类型
        if (!StringUtils.isEmpty(map.get("driverExam")) && Integer.valueOf(map.get("driverExam").toString()) > 0) {
            map.put("driverExam", Integer.valueOf(map.get("driverExam").toString()));
        } else {
            map.remove("driverExam");
        }
        Integer pageNo = Integer.valueOf(map.getOrDefault("page", "1").toString());
        Integer pageSizeNum = (Integer) map.getOrDefault("pageSize", pageSize);
        pageNo = pageNo < 1 ? 1 : pageNo;
        IPage<TauvReportDTO> page = new Page<>(pageNo, pageSizeNum);
        Integer adminId = ShiroUtils.getAdminId();
        SysAdmin adminInfo = iSysAdminService.getAdminInfo(adminId);
        String cityIdStr = adminInfo.getCityIds();
        if (!"1".equals(adminId.toString())) {
            // 谁执行的报告谁生成
            map.put("flightGroup", adminId);
        }
        // 生成的报告必须是已复核完成的
        map.put("inspectStatus", 6);
        // 处理区域问题
        map = FunctionUtils.dealArea(map);
        List<TauvReportDTO> list = reportMapper.getPageDataList(page, map);
        IPage returnMap = getDataDetail(list, page, "getGenerateList");
        return response.success(returnMap);
    }

    /**
     * 报告审核列表
     *
     * @param map
     * @return
     */
    @Override
    public Response getCheckList(Map<String, Object> map) {
        if (StringUtils.isEmpty(map)) {
            map = new HashMap<>();
        }
        if (map.containsKey("inspectStartTime") && !"".equals(map.get("inspectStartTime")) && Integer.valueOf(map.get("inspectStartTime").toString()) > 0) {
            String endTime = FunctionUtils.formatTime(Integer.valueOf(map.get("inspectStartTime").toString()), "yyyy-MM-dd") + " 23:59:59";
            Integer endStamp = FunctionUtils.dateToStamp(endTime);
            map.put("endTime", endStamp);
        }
        // 处理区域
        map = FunctionUtils.dealArea(map);
        Integer pageNo = Integer.valueOf(map.getOrDefault("page", "1").toString());
        Integer pageSizeNum = (Integer) map.getOrDefault("pageSize", pageSize);
        IPage<TauvReportDTO> page = new Page<>(pageNo, pageSizeNum);
        List<TauvReportDTO> list = reportMapper.getCheckList(page, map);
        IPage returnMap = getDataDetail(list, page, "getCheckList");
        return response.success(returnMap);
    }

    /**
     * 报告查询列表
     *
     * @param map
     * @return
     */
    @Override
    public Response getSearchList(Map<String, Object> map) {
        if (StringUtils.isEmpty(map)) {
            map = new HashMap<>();
        }
        if (map.containsKey("status") && !"".equals(map.get("status")) && Integer.valueOf(map.get("status").toString()) > 0) {
            Integer[] status = {Integer.valueOf(map.get("status").toString())};
            map.put("status", status);
        } else {
            Integer[] status = {2, 3, 4};
            map.put("status", status);
        }
        if (map.containsKey("inspectStartTime") && !"".equals(map.get("inspectStartTime")) && Integer.valueOf(map.get("inspectStartTime").toString()) > 0) {
            String endTime = FunctionUtils.formatTime(Integer.valueOf(map.get("inspectStartTime").toString()), "yyyy-MM-dd") + " 23:59:59";
            Integer endStamp = FunctionUtils.dateToStamp(endTime);
            map.put("endTime", endStamp);
        }
        Integer pageNo = Integer.valueOf(map.getOrDefault("page", "1").toString());
        Integer pageSizeNum = (Integer) map.getOrDefault("pageSize", pageSize);
        IPage<TauvReportDTO> page = new Page<>(pageNo, pageSizeNum);
        Integer authPid = iSysAuthGroupService.getAuthGroupPid();
        Integer adminId = ShiroUtils.getAdminId();

        // 区域
        map = FunctionUtils.dealArea(map);
        // 是否国考
        if (map.containsKey("driverExam") && !"".equals(map.get("driverExam"))) {
            map.put("driverExam", Integer.valueOf(map.get("driverExam").toString()));
        } else {
            map.remove("driverExam");
        }

        IPage returnMap;
        Map<String, Object> result = new HashMap<>();
        if (authPid.equals(2)) {
            //外部用户
            Integer[] status = {3};
            map.put("status", status);
            List<TauvReportDTO> list = reportMapper.getPageDataList(page, map);
            returnMap = getDataDetail(list, page, "getSearchList");
            Map<Integer, String> statusList = new HashMap<>();
            statusList.put(3, "审核通过");
            result.put("data", returnMap);
            result.put("statusList", statusList);
        } else {
            map.put("adminId", adminId);
            List<TauvReportDTO> list = reportMapper.getInnerUserSearchDataList(page, map);
            returnMap = getDataDetail(list, page, "getInnerUserSearchDataList");
            result.put("data", returnMap);
            TauvReport report = new TauvReport();
            result.put("statusList", report.getStatusList());
        }
        return response.success(result);
    }

    /**
     * 报告录入列表
     *
     * @param map
     * @return
     */
    @Override
    public Response getInputList(Map<String, Object> map) {
        if (StringUtils.isEmpty(map)) {
            map = new HashMap<>();
        }
        TauvReportInputDTO inputDTO = new TauvReportInputDTO();
        Map<Integer, String> statusList = inputDTO.getStatusList();
        List<Map<String, Object>> cityList = iSysCityService.getCityListByPid(320100);
        if (map.containsKey("inspectStartTime") && !"".equals(map.get("inspectStartTime")) && Integer.valueOf(map.get("inspectStartTime").toString()) > 0) {
            String endTime = FunctionUtils.formatTime(Integer.valueOf(map.get("inspectStartTime").toString()), "yyyy-MM-dd") + " 23:59:59";
            Integer endStamp = FunctionUtils.dateToStamp(endTime);
            map.put("endTime", endStamp);
        }
        // 区域
        map = FunctionUtils.dealArea(map);

        Integer pageNo = Integer.valueOf(map.getOrDefault("page", "1").toString());
        Integer pageSizeNum = (Integer) map.getOrDefault("pageSize", pageSize);
        IPage<TauvReportInputDTO> page = new Page<>(pageNo, pageSizeNum);
        List<TauvReportInputDTO> list = reportMapper.getInputList(page, map);
        if (!StringUtils.isEmpty(list)) {
            String format = "yyyy-MM-dd HH:mm:ss";
            for (TauvReportInputDTO reportInputDTO : list) {
                if (!StringUtils.isEmpty(reportInputDTO.getDriverArea())) {
                    SysCity cityInfo = iSysCityService.getInfoById(reportInputDTO.getDriverArea());
                    reportInputDTO.setDriverAreaText(StringUtils.isEmpty(cityInfo) ? "" : cityInfo.getName());
                }
                reportInputDTO.setFormatInspectStartTime(StringUtils.isEmpty(reportInputDTO.getInspectStartTime()) ? "" : FunctionUtils.formatTime(reportInputDTO.getInspectStartTime(), format));
                if (!StringUtils.isEmpty(reportInputDTO.getVideoUrl())) {
                    String videoUrl = reportInputDTO.getVideoUrl();
                    if (!videoUrl.contains("://")) {
                        videoUrl = uploadUrl + videoUrl;
                    }
                    reportInputDTO.setVideoUrl(videoUrl);
                }
                if (!StringUtils.isEmpty(reportInputDTO.getOriginalVideoUrl())) {
                    String originalVideoUrl = reportInputDTO.getOriginalVideoUrl();
                    if (!originalVideoUrl.contains("://")) {
                        originalVideoUrl = uploadUrl + reportInputDTO.getOriginalVideoUrl();
                    }
                    reportInputDTO.setOriginalVideoUrl(originalVideoUrl);
                }
                if (!StringUtils.isEmpty(reportInputDTO.getImageUrl())) {
                    String imgUrl = reportInputDTO.getImageUrl();
                    if (!imgUrl.contains("://")) {
                        imgUrl = uploadUrl + imgUrl;
                    }
                    reportInputDTO.setImageUrl(imgUrl);
                }
                if (!StringUtils.isEmpty(reportInputDTO.getReportUrl())) {
                    String reportUrl = reportInputDTO.getReportUrl();
                    if (!reportUrl.contains("://") && Integer.valueOf(reportUrl) != 0) {
                        reportUrl = uploadUrl + reportUrl;
                    }
                    reportInputDTO.setReportUrl(reportUrl);
                }
                if (!StringUtils.isEmpty(reportInputDTO.getInputUser())) {
                    SysAdmin inputUser = iSysAdminService.getAdminInfo(reportInputDTO.getInputUser());
                    reportInputDTO.setFormatInputUser(StringUtils.isEmpty(inputUser) ? "" : inputUser.getRealname());
                }
                if (!StringUtils.isEmpty(reportInputDTO.getInputTime())) {
                    reportInputDTO.setFormatInputTime(FunctionUtils.formatTime(reportInputDTO.getInputTime(), format));
                }
                TauvInspectDriver driver = inspectDriverMapper.selectById(reportInputDTO.getInspectDriverId());
                reportInputDTO.setNum(driver.getNum());
            }
        }
        page.setRecords(list);
        return response.success(page);
    }

    /**
     * 根据编号获取数据详细信息
     *
     * @param id
     * @param actType
     * @return
     */
    @Override
    public Map<String, Object> getDetailById(Integer id, String actType) {
        if (StringUtils.isEmpty(id)) {
            return null;
        }
        Map<String, Object> data = new HashMap<>();
        TauvReport reportInfo = getInfoById(id);
        if (StringUtils.isEmpty(reportInfo)) {
            return null;
        }
        data.put("id", reportInfo.getId());
        data.put("driverName", reportInfo.getDriverName());
        data.put("reportNo", reportInfo.getReportNo());
        data.put("manyiCheckScore", reportInfo.getManyiCheckScore());
        data.put("manyiExamineScore", reportInfo.getManyiExamineScore());
        data.put("awareExamineScore", reportInfo.getAwareExamineScore());
        data.put("awareCheckScore", reportInfo.getAwareCheckScore());
        data.put("totalExamineScore", reportInfo.getTotalExamineScore());
        data.put("totalCheckScore", reportInfo.getTotalCheckScore());
        data.put("status", reportInfo.getStatus());
        data.put("desc", reportInfo.getDesc());
        if (!StringUtils.isEmpty(reportInfo.getDriverArea())) {
            SysCity cityInfo = iSysCityService.getInfoById(reportInfo.getDriverArea());
            data.put("driverArea", StringUtils.isEmpty(cityInfo) ? "" : cityInfo.getName());
        }
        if (!StringUtils.isEmpty(reportInfo.getVideoUrl())) {
            data.put("videoUrl", reportInfo.getVideoUrl());
        } else {
            data.put("videoUrl", "");
        }
        if (!StringUtils.isEmpty(reportInfo.getImageUrl())) {
            data.put("imageUrl", reportInfo.getImageUrl());
        } else {
            data.put("imageUrl", "");
        }
        /**飞行任务相关数据*/
        TauvInspectDriver inspectDriverInfo = inspectDriverMapper.selectById(reportInfo.getInspectDriverId());
        if (!StringUtils.isEmpty(inspectDriverInfo)) {
            data.put("weather", inspectDriverInfo.getWeather());
            data.put("wind", inspectDriverInfo.getWind());
            data.put("temperature", inspectDriverInfo.getTemperature());
            data.put("flightSpeed", inspectDriverInfo.getFlightSpeed());
            data.put("flightHeight", inspectDriverInfo.getFlightHeight());
            data.put("flightTime", inspectDriverInfo.getFlightTime());
        } else {
            data.put("weather", "");
            data.put("wind", "");
            data.put("temperature", "");
            data.put("flightSpeed", "");
            data.put("flightHeight", "");
            data.put("flightTime", "");
        }
        /*问题列表*/
        TauvQuestionOptions question = new TauvQuestionOptions();
        Map<Integer, String> categoryList = question.getCategoryList();
        Map<Integer, String> typeList = question.getTypeList();

        List<TauvQuestionOptions> questionData = iTauvQuestionOptionsService.getDataList();
        List<Map<String, Object>> questionList = new ArrayList<>();
        Integer totalExamineScore = 0;
        Integer totalCheckScore = 0;
        TauvDriver driverInfo = tauvDriverService.getInfoById(inspectDriverInfo.getDriverId());
        for (TauvQuestionOptions questionOptions : questionData) {
            Map<String, Object> questionMap = new HashMap<>();
            /*获取复核有效的图片数量*/
            Integer questionNum = iTauvInspectFileService.getReviewNumByInspectDriverId(questionOptions.getId(), reportInfo.getInspectDriverId());
            TauvReportRemark remarkInfo = iTauvReportRemarkService.getInfoByReportIdAndQuestionId(reportInfo.getId(), questionOptions.getId());
            Integer category = questionOptions.getCategory();
            Integer type = questionOptions.getType();
            questionMap.put("category", category);
            questionMap.put("categoryText", categoryList.get(category.intValue()));
            questionMap.put("type", type);
            questionMap.put("typeText", typeList.get(type.intValue()));
            questionMap.put("questionNum", questionNum);
            questionMap.put("remark", StringUtils.isEmpty(remarkInfo) ? "" : remarkInfo.getRemark());

            questionMap.put("content", questionOptions.getContent());
            questionMap.put("note", questionOptions.getNote());
            questionMap.put("id", questionOptions.getId());

            /*考核分*/
            if (!StringUtils.isEmpty(questionOptions.getIncreaseNum()) && "generate".equals(actType)) {
                Double number = Math.ceil(Double.valueOf(questionNum) / questionOptions.getIncreaseNum());
                Integer integer = (new Double(number)).intValue();
                Integer deduction = questionOptions.getDeduction();
                Integer examineScore = 0;
//                if (driverInfo.getIsExam() == 1) {
//                    examineScore = questionOptions.getExamBaseScore() - integer * deduction;
//                } else {
//                    examineScore = questionOptions.getBaseScore() - integer * deduction;
//                }
                examineScore = questionOptions.getBaseScore() - integer * deduction;
                examineScore = examineScore > 0 ? examineScore : 0;
                questionMap.put("examineScore", examineScore);
                questionMap.put("checkScore", examineScore);
                totalCheckScore += examineScore;
                totalExamineScore += examineScore;
            } else {
                questionMap.put("examineScore", StringUtils.isEmpty(remarkInfo) ? "" : remarkInfo.getExamineScore());
                questionMap.put("checkScore", StringUtils.isEmpty(remarkInfo) ? "" : remarkInfo.getCheckScore());
            }
            questionList.add(questionMap);
        }
        data.put("questionList", questionList);
        if ("generate".equals(actType)) {
            data.put("totalCheckScore", totalCheckScore);
            data.put("totalExamineScore", totalExamineScore);
        }
        /*报告描述*/
        List<Map<String, Object>> reportDescList = iTauvReportEvaluationService.getDataByStatus(1);
        data.put("reportDescList", reportDescList);
        /*问题清单*/
        List<Map<String, Object>> questionFileList = iTauvInspectFileService.getReviewDataByInspectDriverId(reportInfo.getInspectDriverId());
        if (!StringUtils.isEmpty(questionFileList)) {
            for (Map<String, Object> questionF : questionFileList) {
                if (questionF.get("status").toString().equals("1")) {
                    String questionId = questionF.getOrDefault("question_id", 0).toString();
                    if (!StringUtils.isEmpty(questionId)) {
                        TauvQuestionOptions qInfo = iTauvQuestionOptionsService.getInfoById(Integer.valueOf(questionId));
                        questionF.put("questionContent", StringUtils.isEmpty(qInfo) ? "" : qInfo.getContent());
                    }
                }
                if (!StringUtils.isEmpty(questionF.get("src"))) {
                    questionF.put("formatSrc", uploadUrl + questionF.get("src"));
                    questionF.put("formatOriginalImg", uploadUrl + questionF.get("original_img"));
                } else {
                    questionF.put("formatSrc", "");
                    questionF.put("formatOriginalImg", "");
                }
                questionF.put("location", questionF.get("baidu_address"));
                questionF.put("baiduLatitude", questionF.get("baidu_latitude"));
                questionF.put("baiduLongitude", questionF.get("baidu_longitude"));
            }
        }
        data.put("questionFileList", questionFileList);
        /*审核记录列表*/
        if ("edit".equals(actType)) {
            List<TauvReportCheck> reportChecksList = iTauvReportCheckService.getListByReportId(reportInfo.getId());
            if (null != reportChecksList) {
                for (TauvReportCheck reportCheck : reportChecksList) {
                    Integer checkUser = reportCheck.getCheckUser();
                    Date createTime = reportCheck.getCreateTime();
                    reportCheck.setFormatCreateTime(createTime.toString());
//                    reportCheck.setFormatCreateTime(FunctionUtils.formatTime(createTime, "yyyy-MM-dd HH:mm:ss"));
                    SysAdmin adminInfo = iSysAdminService.getAdminInfo(checkUser);
                    reportCheck.setFormatCheckUser(adminInfo.getRealname());
                }
            }
            data.put("reportCheckList", reportChecksList);
        }
        data.put("questionFileList", questionFileList);
        String format = "yyyy-MM-dd HH:mm:ss";
        data.put("inspectStartTime", StringUtils.isEmpty(reportInfo.getInspectStartTime()) ? "" : DateUtil.format(reportInfo.getInspectStartTime(), format));
        data.put("driverStart", reportInfo.getDriverStart());
        data.put("driverEnd", reportInfo.getDriverEnd());
        data.put("inspectLength", reportInfo.getInspectLength());
//        data.put("driverExam", driverInfo.getIsExam());
        return data;
    }

    /**
     * 生成、编辑报告
     *
     * @param map
     * @param act
     * @return
     */
    @Override
    public Response editSub(Map<String, Object> map, String act) {
        if (StringUtils.isEmpty(map)) {
            return response.failure("参数不能为空");
        }
        Integer id = Integer.valueOf(map.get("id").toString());
        if (StringUtils.isEmpty(id)) {
            return response.failure("编号不存在");
        }
        TauvReport info = getInfoById(id);
        if (StringUtils.isEmpty(info)) {
            return response.failure("数据不存在");
        }
        TauvReport tauvReport = new TauvReport();
        String videoUrl = map.getOrDefault("videoUrl", "").toString();
        String imageUrl = map.getOrDefault("imageUrl", "").toString();
        //群众满意度考核分
        String manyiExamineScore = map.getOrDefault("manyiExamineScore", "0").toString();
        //群众满意度校核分
        String manyiCheckScore = map.getOrDefault("manyiCheckScore", "0").toString();
        //群众知晓率考核分
        String awareExamineScore = map.getOrDefault("awareExamineScore", "0").toString();
        //群众知晓率校核分
        String awareCheckScore = map.getOrDefault("awareCheckScore", "0").toString();
        String totalExamineScore = map.getOrDefault("totalExamineScore", "0").toString();
        String totalCheckScore = map.getOrDefault("totalCheckScore", "0").toString();
        if (map.containsKey("desc") && !"".equals(map.get("desc"))) {
            String desc = map.getOrDefault("desc", "").toString();
            if (desc.length() > 200) {
                return response.failure("报告描述不能超过200字");
            }
            tauvReport.setDesc(desc);
        }
        if (StringUtils.isEmpty(info.getReportNo())) {
            String num = String.format("%04d", info.getId());
            String reportNo = "BG" + FunctionUtils.formatTime(FunctionUtils.getCurrentTime(), "yyyyMM") + num;
            tauvReport.setReportNo(reportNo);
        }
        if (!StringUtils.isEmpty(videoUrl)) {
            tauvReport.setVideoUrl(videoUrl);
        }
        if (!StringUtils.isEmpty(imageUrl)) {
            tauvReport.setImageUrl(imageUrl);
        }
        tauvReport.setManyiExamineScore(StringUtils.isEmpty(manyiExamineScore) ? 0 : Integer.valueOf(manyiExamineScore));
        tauvReport.setManyiCheckScore(StringUtils.isEmpty(manyiCheckScore) ? 0 : Integer.valueOf(manyiCheckScore));
        tauvReport.setAwareExamineScore(StringUtils.isEmpty(awareExamineScore) ? 0 : Integer.valueOf(awareExamineScore));
        tauvReport.setAwareCheckScore(StringUtils.isEmpty(awareCheckScore) ? 0 : Integer.valueOf(awareCheckScore));
        tauvReport.setTotalExamineScore(StringUtils.isEmpty(totalExamineScore) ? 0 : Integer.valueOf(totalExamineScore));
        tauvReport.setTotalCheckScore(StringUtils.isEmpty(totalCheckScore) ? 0 : Integer.valueOf(totalCheckScore));
        tauvReport.setId(id);
        Integer status = 0;
        /*审核操作*/
        if (map.containsKey("status")) {
            String statusStr = map.getOrDefault("status", "").toString();
            if (!statusStr.equals("3") && !statusStr.equals("4")) {
                return response.failure("状态不合法");
            }
            status = Integer.valueOf(statusStr);
            tauvReport.setStatus(status);

        }
        //生成报告-修改状态为“审核中”
        if ("generate".equals(act)) {
            tauvReport.setStatus(Integer.valueOf("2"));
            tauvReport.setInputTime(FunctionUtils.getCurrentTime());
            tauvReport.setInputUser(ShiroUtils.getAdminId());
        }
        reportMapper.updateById(tauvReport);

        String remark = "";
        if (map.containsKey("remark")) {
            remark = map.getOrDefault("remark", "").toString();
            if (remark.length() > 200) {
                return response.failure("审核意见不能超过200字");
            }
        }
        if ("checkSub".equals(act)) {
            checkSub(id, info.getInspectDriverId(), remark, status);
        }
        /*删除历史记录*/
        iTauvReportRemarkService.deleteByReportId(info.getId());
        if (!map.containsKey("examineScore") || map.size() < 1) {
            return response.failure("考核参数不能为空");
        }
        List<Map<String, Object>> examineScore = (List<Map<String, Object>>) map.getOrDefault("examineScore", "");
        if (StringUtils.isEmpty(examineScore)) {
            return response.failure("考核参数不正确");
        }
        String msg = "";
        for (Map<String, Object> exam : examineScore) {
            remark = !StringUtils.isEmpty(exam.get("remark")) ? exam.get("remark").toString() : "";
            if (remark.length() > 200) {
                msg = "备注不能超过200个字";
                break;
            }
            TauvReportRemark reportRemark = new TauvReportRemark();
            reportRemark.setReportId(info.getId());
            reportRemark.setQuestionId(Integer.valueOf(exam.get("questionId").toString()));
            Integer examScore = 0;
            if (exam.containsKey("examineScore") && !"".equals(exam.get("examineScore")) && Integer.valueOf(exam.get("examineScore").toString()) > 0) {
                examScore = Integer.valueOf(exam.get("examineScore").toString());
            }
            reportRemark.setExamineScore(examScore);
            Integer checkScore = 0;
            if (exam.containsKey("checkScore") && !"".equals(exam.get("checkScore")) && Integer.valueOf(exam.get("checkScore").toString()) > 0) {
                checkScore = Integer.valueOf(exam.get("checkScore").toString());
            }
            reportRemark.setCheckScore(checkScore);
            reportRemark.setRemark(remark);
            iTauvReportRemarkService.addData(reportRemark);
        }
        if (!StringUtils.isEmpty(msg)) {
            return response.failure(msg);
        }
        /*更新图片描述信息*/
        if (map.containsKey("descriptionList")) {
            List<Map<String, String>> descriptionList = (List<Map<String, String>>) map.getOrDefault("descriptionList", "");
            for (Map<String, String> descList : descriptionList) {
                TauvInspectFile inspectFile = new TauvInspectFile();
                String fileId = descList.get("id");
                String descName = descList.get("description");
                inspectFile.setId(Integer.valueOf(fileId));
                inspectFile.setDescription(descName);
                iTauvInspectFileService.updateById(inspectFile);
            }
        }

        return response.success("操作成功");
    }

    /**
     * 编辑图片和视频地址
     *
     * @param map
     * @return
     */
    @Override
    public Response editUrl(Map<String, Object> map) {
        if (StringUtils.isEmpty(map)) {
            return response.failure("参数不能为空");
        }
        Integer id = Integer.valueOf(map.get("id").toString());
        if (StringUtils.isEmpty(id)) {
            return response.failure("编号不存在");
        }
        TauvReport info = getInfoById(id);
        if (StringUtils.isEmpty(info)) {
            return response.failure("数据不存在");
        }
        TauvReport tauvReport = new TauvReport();
        String originalVideoUrl = "";
        if (map.containsKey("originalVideoUrl") && map.get("originalVideoUrl") != null) {
            originalVideoUrl = map.getOrDefault("originalVideoUrl", "").toString();
        }
        String videoUrl = map.containsKey("videoUrl") && !StringUtils.isEmpty(map.get("videoUrl")) ? map.get("videoUrl").toString() : "";
        String imgUrl = map.containsKey("imageUrl") && !StringUtils.isEmpty(map.get("imageUrl")) ? map.get("imageUrl").toString() : "";
        String reportUrl = "";
        if (!StringUtils.isEmpty(map.get("reportUrl"))) {
            reportUrl = map.getOrDefault("reportUrl", "").toString();
        }
        tauvReport.setOriginalVideoUrl(originalVideoUrl);
        tauvReport.setVideoUrl(videoUrl);
        tauvReport.setImageUrl(imgUrl);
        tauvReport.setReportUrl(reportUrl);
        tauvReport.setUpdateTime(DateUtil.now());
        tauvReport.setUpdateUser(ShiroUtils.getAdminId());
        tauvReport.setId(id);
        reportMapper.updateById(tauvReport);
        return response.success("操作成功");
    }

    /**
     * 报告审核
     *
     * @param reportId
     * @param inspectDriverId
     * @param remark
     * @return
     */
    private void checkSub(Integer reportId, Integer inspectDriverId, String remark, Integer status) {
        TauvInspectDriver inspectDriver = new TauvInspectDriver();
        inspectDriver.setId(inspectDriverId);
        inspectDriver.setStatus(Integer.valueOf("4"));
        inspectDriverMapper.updateById(inspectDriver);
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("mark", 1);
        wrapper.eq("report_id", reportId);
        TauvReportCheck reportCheck = iTauvReportCheckService.getOne(wrapper);
        if (reportCheck == null) {
            reportCheck = new TauvReportCheck();
        }
        reportCheck.setReportId(reportId);
        reportCheck.setStatus(status);
        if (!StringUtils.isEmpty(remark)) {
            reportCheck.setRemark(remark);
        }
        iTauvReportCheckService.addData(reportCheck);
    }

    /**
     * 根据编号获取数据
     *
     * @param id
     * @return
     */
    @Override
    public TauvReport getInfoById(Integer id) {
        TauvReport info = reportMapper.selectById(id);
        if (null != info) {
            info.setFormatImageUrl(imageUrl + info.getImageUrl());
            info.setFormatVideoUrl(imageUrl + info.getVideoUrl());
            if (!StringUtils.isEmpty(info.getDriverArea())) {
                SysCity city = iSysCityService.getInfoById(info.getDriverArea());
                info.setDriverAreaText(StringUtils.isEmpty(city) ? "" : city.getName());
            } else {
                info.setDriverAreaText("");
            }
            info.setFormatInspectStartTime(StringUtils.isEmpty(info.getInspectStartTime()) ? "" : DateUtil.format(info.getInspectStartTime(), "yyyy-MM-dd HH:mm:ss"));
        }
        return info;
    }

    /**
     * 根据条件获取河道数量
     *
     * @param map
     * @return
     */
    @Override
    public Integer getNumByCond(Map<String, String> map) {
        Boolean question = map.containsKey("question") && !"".equals(map.get("question")) ? true : false;
        QueryWrapper<TauvReport> wrapper = new QueryWrapper<>();
        Map<String, Object> query = new HashMap<>();
        if (map.containsKey("driverExam")) {
            Byte driverExam = Byte.valueOf(map.getOrDefault("driverExam", "1"));
            wrapper.eq("driver_exam", driverExam);
            query.put("driverExam", driverExam);
        }

        String[] driverAreaStr = new String[]{""};
        if (map.containsKey("driverArea") && !StringUtils.isEmpty(map.get("driverArea"))) {
            driverAreaStr = map.get("driverArea").split(",");
            wrapper.in("driver_area", (Integer[]) ConvertUtils.convert(driverAreaStr, Integer.class));
        }
        query.put("driverArea", (Integer[]) ConvertUtils.convert(driverAreaStr, Integer.class));
        wrapper.eq("status", Byte.valueOf("3"));

        Integer startTime = 0;
        Integer endTime = 0;
        if (!FunctionUtils.isEmpty("startTime", map)) {
            startTime = FunctionUtils.dateToStamp(map.get("startTime"));
        }
        if (!FunctionUtils.isEmpty("endTime", map)) {
            endTime = FunctionUtils.dateToStamp(map.get("endTime"));
        }
        if (!StringUtils.isEmpty(startTime) && !StringUtils.isEmpty(endTime) && startTime > 0 && endTime > 0) {
            wrapper.between("inspect_start_time", startTime, endTime);
            query.put("startTime", startTime);
            query.put("endTime", endTime);
        }
        Map<String, Object> list = reportMapper.selectDriverCount(query);
        if (question) {
            return Integer.valueOf(list.get("number").toString());
        } else {
            wrapper.select("distinct driver_name");
            return reportMapper.selectCount(wrapper);
        }
    }

    /**
     * 根据条件获取报告数据
     *
     * @param map
     * @param order 列如： id asc
     * @return
     */
    @Override
    public IPage<TauvReport> getListByCond(Map<String, String> map, String order) {
        TauvReport tauvReport = new TauvReport();
        QueryWrapper<TauvReport> wrapper = new QueryWrapper<>();
        wrapper.eq("mark", 1);
        wrapper.eq("status", Byte.valueOf("3"));
        Byte driverExam = Byte.valueOf(map.getOrDefault("driverExam", "1"));
        //Integer driverArea = Integer.valueOf(map.get("driverArea"));
        wrapper.eq("driver_exam", driverExam);
        //wrapper.eq("driver_area", driverArea);
        Integer startTime = 0;
        Integer endTime = 0;
        if (!FunctionUtils.isEmpty("startTime", map)) {
            startTime = FunctionUtils.dateToStamp(map.get("startTime"));
        }
        if (!FunctionUtils.isEmpty("endTime", map)) {
            endTime = FunctionUtils.dateToStamp(map.get("endTime"));
        }
        if (!StringUtils.isEmpty(startTime) && startTime > 0 && !StringUtils.isEmpty(endTime) && endTime > 0) {
            wrapper.between("inspect_start_time", startTime, endTime);
        }
        if (map.containsKey("driverArea") && !StringUtils.isEmpty(map.get("driverArea"))) {
            String[] driverAreaStr = map.get("driverArea").split(",");
            Integer[] driverArea = (Integer[]) ConvertUtils.convert(driverAreaStr, Integer.class);
            wrapper.in("driver_area", driverArea);
        } else {
            wrapper.in("driver_area", "");
        }
        if (!StringUtils.isEmpty(order)) {
            String[] orderArr = order.split(" ");
            if ("asc".equalsIgnoreCase(orderArr[1])) {
                wrapper.orderByAsc(orderArr[0]);
            } else {
                wrapper.orderByDesc(orderArr[0]);
            }
        }
        Integer pageNo = StringUtils.isEmpty(map.get("page")) ? 1 : Integer.valueOf(map.get("page"));
        Integer pageSizeNo = StringUtils.isEmpty(map.get("pageSize")) ? pageSize : Integer.valueOf(map.get("pageSize"));
        IPage<TauvReport> page = new Page<>(pageNo, pageSizeNo);
        return reportMapper.selectPage(page, wrapper);
    }

    /**
     * 根据条件获取数据列表
     *
     * @param map
     * @return
     */
    @Override
    public List<TauvReport> getDataListByCond(Map<String, String> map) {
        QueryWrapper<TauvReport> wrapper = new QueryWrapper<>();
        wrapper.eq("mark", 1);
        if (map.containsKey("status")) {
            wrapper.eq("status", Byte.valueOf(map.get("status")));
        }
        if (map.containsKey("driverArea") && !StringUtils.isEmpty(map.get("driverArea"))) {
            String[] driverAreaStr = map.get("driverArea").split(",");
            Integer[] driverArea = (Integer[]) ConvertUtils.convert(driverAreaStr, Integer.class);
            wrapper.in("driver_area", driverArea);
        }
        if (map.containsKey("field")) {
            wrapper.select(map.get("field"));
        }
        return reportMapper.selectList(wrapper);
    }

    /**
     * 数据处理
     *
     * @param list
     * @param page
     * @return
     */
    private IPage getDataDetail(List<TauvReportDTO> list, IPage<TauvReportDTO> page, String act) {
        TauvReport report = new TauvReport();
        Map<Integer, String> statusList = report.getStatusList();
        if (list != null) {
            String format = "yyyy-MM-dd HH:mm:ss";
            for (TauvReportDTO reportDTO : list) {
                if (!StringUtils.isEmpty(reportDTO.getDriverArea())) {
                    SysCity cityInfo = iSysCityService.getInfoById(reportDTO.getDriverArea());
                    reportDTO.setDriverAreaText(StringUtils.isEmpty(cityInfo) ? "" : cityInfo.getName());
                }
                if (reportDTO.getInputTime() > 0) {
                    reportDTO.setCreateTime(reportDTO.getInputTime());
                    reportDTO.setFormatInputTime(FunctionUtils.formatTime(reportDTO.getInputTime(), "yyyy-MM-dd HH:mm:ss"));
                } else {
                    reportDTO.setFormatInputTime("");
                }
                reportDTO.setStatusText(statusList.getOrDefault(reportDTO.getStatus().intValue(), ""));
                reportDTO.setFormatInspectStartTime(StringUtils.isEmpty(reportDTO.getInspectStartTime()) ? "" : FunctionUtils.formatTime(reportDTO.getInspectStartTime(), format));
                TauvInspectDriver driverInfo = inspectDriverMapper.selectById(reportDTO.getInspectDriverId());
                if (!StringUtils.isEmpty(driverInfo)) {
                    reportDTO.setNum(driverInfo.getNum());
                    reportDTO.setFlightTime(driverInfo.getFlightTime());
                }
                if (!StringUtils.isEmpty(reportDTO.getVideoUrl())) {
                    String videoUrl = reportDTO.getVideoUrl();
                    if (!videoUrl.contains("://")) {
                        reportDTO.setVideoUrl(uploadUrl + videoUrl);
                    }
                }
                if (!StringUtils.isEmpty(reportDTO.getImageUrl())) {
                    String imgUrl = reportDTO.getImageUrl();
                    if (!imgUrl.contains("://")) {
                        reportDTO.setImageUrl(uploadUrl + imgUrl);
                    }
                }
            }
        }
        page.setRecords(list);
        return page;
    }

    /**
     * 处理报告
     *
     * @param map
     * @param act
     * @return
     */
    @Override
    public Response dealReport(Map<String, Object> map, String act) {
        if (StringUtils.isEmpty(map)) {
            return response.failure("参数不能为空");
        }
        String idStr = "id";
        if (StringUtils.isEmpty(map.get(idStr))) {
            return response.failure("报告id不能为空");
        } else {
            Integer id = Integer.valueOf(map.get(idStr).toString());
            if (id <= 0) {
                return response.failure("报告id不合法");
            }
            QueryWrapper wrapper = new QueryWrapper();
            wrapper.eq("mark", 1);
            wrapper.eq("id", id);
            TauvReport reportInfo = reportMapper.selectOne(wrapper);
            if (reportInfo == null) {
                return response.failure("报告数据不存在");
            }
            if ("drop".equals(act)) {
                reportInfo.setMark(0);
            } else {
                reportInfo.setStatus(Integer.valueOf("2"));
            }
            reportMapper.updateById(reportInfo);
            return response.success("操作成功");
        }
    }
}
