package com.taauav.front.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.taauav.common.bean.Response;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.JwtUtil;
import com.taauav.common.util.StringUtils;
import com.taauav.front.dto.LoginDto;
import com.taauav.admin.entity.LsAdmin;
import com.taauav.admin.mapper.LsAdminMapper;
import com.taauav.front.service.ILsLoginService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * 外部人员表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2020-04-01
 */
@Service
public class LsLoginServiceImpl extends ServiceImpl<LsAdminMapper, LsAdmin> implements ILsLoginService {

    @Autowired
    private Response response;

    @Autowired
    private LsAdminMapper adminMapper;

    /**
     * 系统登录
     *
     * @param loginDto 参数
     * @return
     */
    @Override
    public Response login(LoginDto loginDto) {
        // 用户名校验
        if (StringUtils.isEmpty(loginDto.getUsername())) {
            return response.failure("登录用户名不能为空");
        }
        // 登录密码校验
        if (StringUtils.isEmpty(loginDto.getPassword())) {
            return response.failure("登录密码不能为空");
        }
        // 根据用户名获取用户信息
        QueryWrapper<LsAdmin> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("username", loginDto.getUsername());
        queryWrapper.eq("mark", 1);
        LsAdmin adminInfo = adminMapper.selectOne(queryWrapper);
        if (adminInfo == null) {
            return response.failure("用户信息不存在");
        }
        // 校验密码是否正确
        if (!adminInfo.getPassword().equals(FunctionUtils.password(loginDto.getPassword()))) {
            return response.failure("登录密码不正确");
        }
        // 校验用户状态
        if (adminInfo.getStatus() != 1) {
            return response.failure("您已被禁用,请联系管理员");
        }
        // 生成token给前端
        String token = JwtUtil.createJWT(1);
//        System.out.print("token:" + token);
//        Claims data = JwtUtil.parseJWT(token);
//        System.out.println(data);
//        System.out.println("用户ID：" + data.get("id"));
//
//        Boolean isOK = JwtUtil.isVerify(token, 1);
//        System.out.print(isOK);

        Map<String, String> result = new HashMap<>();
        result.put("token", token);
        return response.success("登录成功", result);
    }

}
